@@ -1,6 +1,3 @@
-#' @include get_RLum.R set_RLum.R names_RLum.R length_RLum.R bin_RLum.Data.R smooth_RLum.R
-NULL
-
 #' Class `"RLum.Data.Curve"`
 #'
 #' Class for representing luminescence curve data.
@@ -13,7 +10,8 @@ NULL
 #' Object of class "character" containing the type of the curve (e.g. "TL" or "OSL")
 #'
 #' @slot curveType
-#' Object of class "character" containing curve type, allowed values are measured or predefined
+#' Object of class "character" containing curve type, allowed values are
+#' "measured" or "predefined"
 #'
 #' @slot data
 #' Object of class [matrix] containing curve x and y data.
@@ -25,8 +23,8 @@ NULL
 #'          recordType = 'never seen before')
 #' ```
 #' would just change the `recordType`. Missing arguments  the value is taken
-#' from the input object in 'data' (which is already an RLum.Data.Curve object
-#' in this example)
+#' from the input object in 'data' (which is already an `RLum.Data.Curve`
+#' object in this example)
 #'
 #'
 #' @note
@@ -55,7 +53,6 @@ NULL
 #' ##set empty curve object
 #' set_RLum(class = "RLum.Data.Curve")
 #'
-#' @md
 #' @export
 setClass("RLum.Data.Curve",
          slots = list(
@@ -71,7 +68,7 @@ setClass("RLum.Data.Curve",
            )
          )
 
-# as() ----------------------------------------------------------------------------------------
+## as() ---------------------------------------------------------------------
 ##LIST
 ##COERCE RLum.Data.Curve >> list AND list >> RLum.Data.Curve
 #' as() - RLum-object coercion
@@ -80,7 +77,7 @@ setClass("RLum.Data.Curve",
 #'
 #' **[RLum.Data.Curve-class]**
 #'
-#' \tabular{ll}{
+#' \tabular{lll}{
 #'  **from** \tab **to**\cr
 #'   `list` \tab `list` \cr
 #'   `data.frame` \tab `data.frame`\cr
@@ -99,11 +96,11 @@ setClass("RLum.Data.Curve",
 #' Due to the complex structure of the `RLum` objects itself a coercing to standard
 #' R data structures will be always loosely!
 #'
-#' @md
 #' @name as
 setAs("list", "RLum.Data.Curve",
       function(from,to){
-
+        if (length(from) == 0)
+          return(set_RLum("RLum.Data.Curve"))
         new(to,
             recordType = "unknown curve type",
             curveType = NA_character_,
@@ -115,7 +112,6 @@ setAs("list", "RLum.Data.Curve",
 setAs("RLum.Data.Curve", "list",
       function(from){
           list(x = from@data[,1], y = from@data[,2])
-
       })
 
 ##DATA.FRAME
@@ -132,10 +128,8 @@ setAs("data.frame", "RLum.Data.Curve",
 
 setAs("RLum.Data.Curve", "data.frame",
       function(from){
-
         data.frame(x = from@data[,1],
                    y = from@data[,2])
-
       })
 
 
@@ -148,22 +142,17 @@ setAs("matrix", "RLum.Data.Curve",
             curveType = NA_character_,
             data = from,
             info = list())
-
       })
 
 setAs("RLum.Data.Curve", "matrix",
       function(from){
         from@data
-
       })
 
-# show() --------------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Curve
-#' Show structure of `RLum.Data.Curve` object
+## show() -------------------------------------------------------------------
+#' @describeIn show
+#' Show the structure of `RLum.Data.Curve` objects.
 #'
-#' @keywords internal
-#'
-#' @md
 #' @export
 setMethod("show",
           signature(object = "RLum.Data.Curve"),
@@ -185,45 +174,26 @@ setMethod("show",
           }
 )
 
-# set_RLum() ----------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Curve
-#' Construction method for RLum.Data.Curve object. The slot info is optional
-#' and predefined as empty list by default.
+## set_RLum() ---------------------------------------------------------------
+#' @describeIn set_RLum
+#' Construction method for [RLum.Data.Curve-class] objects.
 #'
-#' @param class [`set_RLum`]; [character] (**required**):
-#' name of the `RLum` class to create
-#'
-#' @param originator [`set_RLum`]; [character] (*automatic*):
-#' contains the name of the calling function (the function that produces this object);
-#' can be set manually.
-#'
-#' @param .uid [`set_RLum`]; [character] (*automatic*):
-#' sets an unique ID for this object using the internal C++ function `create_UID`.
-#'
-#' @param .pid [`set_RLum`]; [character] (*with default*):
-#' option to provide a parent id for nesting at will.
-#'
-#' @param recordType [`set_RLum`]; [character] (*optional*):
+#' @param recordType [character] (*optional*):
 #' record type (e.g., "OSL")
 #'
-#' @param curveType [`set_RLum`]; [character] (*optional*):
+#' @param curveType [character] (*optional*):
 #' curve type (e.g., "predefined" or "measured")
 #'
-#' @param data [`set_RLum`]; [matrix] (**required**):
-#' raw curve data. If `data` itself is a `RLum.Data.Curve`-object this can be
-#' used to re-construct the object (s. details), i.e. modified parameters except
-#' `.uid`, `.pid` and `originator`. The rest will be subject to copy and paste unless provided.
+#' @param data [matrix] or [list] (*with default*):
+#' a matrix containing raw curve data or a list containing the data to be
+#' stored in the object (for [RLum.Results-class] objects) . If `data` itself
+#' is a `RLum.Data.Curve`-object this can be used to re-construct the object,
+#' i.e. modified parameters except `.uid`, `.pid` and `originator`. The rest
+#' will be subject to copy and paste unless provided.
 #'
-#' @param info [`set_RLum`]; [list] (*optional*):
-#' info elements
+#' @param info [list] (*optional*):
+#' a list containing additional info data for the object.
 #'
-#' @return
-#'
-#' **`set_RLum`**
-#'
-#' Returns an [RLum.Data.Curve-class] object.
-#'
-#' @md
 #' @export
 setMethod(
   "set_RLum",
@@ -240,7 +210,7 @@ setMethod(
 
     ##The case where an RLum.Data.Curve object can be provided
     ##with this RLum.Data.Curve objects can be provided to be reconstructed
-    if (is(data, "RLum.Data.Curve")) {
+    if (inherits(data, "RLum.Data.Curve")) {
       ##check for missing curveType
       if (missing(curveType))
         curveType <- data@curveType
@@ -283,38 +253,25 @@ setMethod(
       newRLumDataCurve@info <- info
       newRLumDataCurve@.uid <- .uid
       newRLumDataCurve@.pid <- .pid
-
     }
     return(newRLumDataCurve)
   }
 )
 
-# get_RLum() ----------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Curve
-#' Accessor method for RLum.Data.Curve object. The argument info.object is
-#' optional to directly access the info elements. If no info element name is
-#' provided, the raw curve data (matrix) will be returned.
+## get_RLum() ---------------------------------------------------------------
+#' @describeIn get_RLum
+#' Accessor method for [RLum.Data.Curve-class] object.
+#' The argument `info.object` is optional to directly access the info elements.
+#' If no info element name is provided, the raw curve data (matrix) will be
+#' returned.
 #'
-#' @param object [`get_RLum`], [`length_RLum`], [`names_RLum`] (**required**):
-#' an object of class [RLum.Data.Curve-class]
-#'
-#' @param info.object [`get_RLum`] [character] (*optional*):
-#' name of the wanted info element
-#'
-#' @return
-#'
-#' **`get_RLum`**
-#'
-#' 1. A [matrix] with the curve values or
-#' 2. only the info object if `info.object` was set.
-#'
-#' @md
 #' @export
 setMethod("get_RLum",
           signature("RLum.Data.Curve"),
           definition = function(object, info.object = NULL) {
+          .set_function_name("get_RLum")
+          on.exit(.unset_function_name(), add = TRUE)
 
-           ##if info.object == NULL just show the curve values
            if(!is.null(info.object)) {
               if(info.object %in% names(object@info)){
                 unlist(object@info[info.object])
@@ -322,85 +279,56 @@ setMethod("get_RLum",
               }else{
                 ##check for entries
                 if(length(object@info) == 0){
-                  warning("[get_RLum()] This RLum.Data.Curve object has no info objects! NULL returned!)")
+                  .throw_warning("This RLum.Data.Curve object has no ",
+                                 "info objects, NULL returned")
                   return(NULL)
-
-                }else{
-                  ##grep names
-                  temp.element.names <- paste(names(object@info), collapse = ", ")
-
-                  warning.text <- paste("[get_RLum()] Invalid info.object name. Valid names are:", temp.element.names)
-
-                   warning(warning.text, call. = FALSE)
-                  return(NULL)
-
                 }
-
+                .throw_warning("Invalid 'info.object' name, valid names are: ",
+                               .collapse(names(object@info)))
+                return(NULL)
               }
 
-             }else{
-                object@data
-
-             }
+           } else {
+             ## if info.object == NULL just show the curve values
+             object@data
+           }
           })
 
 
-# length_RLum() -------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Curve
-#' Returns the length of the curve object, which is the maximum of the
-#' value time/temperature of the curve (corresponding to the stimulation length)
+## length_RLum() ------------------------------------------------------------
+#' @describeIn length_RLum
+#' Returns the number of channels in the curve, which is the maximum of the
+#' value time/temperature of the curve (corresponding to the stimulation
+#' length).
 #'
-#' @return
-#'
-#' **`length_RLum`**
-#'
-#' Number of channels in the curve (row number of the matrix)
-#'
-#' @md
 #' @export
 setMethod("length_RLum",
           "RLum.Data.Curve",
           function(object){
             max(object@data[,1])
-
           })
 
 
-# names_RLum() --------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Curve
-#' Returns the names info elements coming along with this curve object
+## names_RLum() -------------------------------------------------------------
+#' @describeIn names_RLum
+#' Returns the names info elements stored in the object.
 #'
-#' @return
-#'
-#' **`names_RLum`**
-#'
-#' Names of the info elements (slot `info`)
-#'
-#' @md
 #' @export
 setMethod("names_RLum",
           "RLum.Data.Curve",
           function(object){
             names(object@info)
-
           })
 
 
-# bin_RLum.Data() -----------------------------------------------------------------------------
-#' @describeIn RLum.Data.Curve
-#' Allows binning of specific objects
+## bin_RLum.Data() ----------------------------------------------------------
+#' @describeIn bin_RLum.Data
+#' Allows binning of RLum.Data.Curve data.
 #'
 #' @param bin_size [integer] (*with default*):
-#' set number of channels used for each bin, e.g. `bin_size = 2` means that
+#' number of channels used for each bin, e.g. `bin_size = 2` means that
 #' two channels are binned.
 #'
-#' @return
-#'
-#' **`bin_RLum.Data`**
-#'
-#' Same object as input, after applying the binning.
-#'
-#' @md
 #' @export
 setMethod(f = "bin_RLum.Data",
           signature = "RLum.Data.Curve",
@@ -438,57 +366,84 @@ setMethod(f = "bin_RLum.Data",
 
               ##just return the object
               return(object)
-
             }
-
           })
 
 
-# smooth_RLum() -------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Curve
-#' Smoothing of RLum.Data.Curve objects using the function [zoo::rollmean] or [zoo::rollmedian][zoo::rollmean].
-#' In particular the internal function `.smoothing` is used.
+## smooth_RLum() ------------------------------------------------------------
+#' @describeIn smooth_RLum
+#' Smoothing of [RLum.Data.Curve-class] objects using a rolling mean or median.
+#' For methods `"mean"` and `"median"`, smoothing is performed by rolling
+#' mean and rolling median with window of size `k`. Method `"Carter_etal_2018"`
+#' implements a Poisson smoother for dark-background signals measured by a
+#' photomultiplier tube.
 #'
 #' @param k [`smooth_RLum`]; [integer] (*with default*):
-#' window for the rolling mean; must be odd for `rollmedian`.
-#' If nothing is set k is set automatically
+#' window for the rolling mean or median. If `NULL`, this set automatically
+#' (ignored if `method = "Carter_etal_2018"`).
 #'
 #' @param fill [`smooth_RLum`]; [numeric] (*with default*):
-#' a vector defining the left and the right hand data
+#' value used to pad the result so to have the same length as the input.
 #'
 #' @param align [`smooth_RLum`]; [character] (*with default*):
-#' specifying whether the index of the result should be left- or right-aligned
-#' or centred (default) compared to the rolling window of observations, allowed
-#' `"right"`, `"center"` and `"left"`
+#' one of `"right"`, `"center"` or `"left"`, specifying whether the index
+#' of the result should be right-aligned (default), centred, or left-aligned
+#' compared to the rolling window of observations (ignored if
+#' `method = "Carter_etal_2018"`).
 #'
 #' @param method [`smooth_RLum`]; [character] (*with default*):
-#' defines which method should be applied for the smoothing: `"mean"` or `"median"`
+#' smoothing method to be applied: one of `"mean"`, `"median"` or
+#' `"Carter_etal_2018"`.
 #'
-#' @return
+#' @param p_acceptance [`smooth_RLum`]; [numeric] (*with default*):
+#' probability threshold of accepting a value to be a sample from a Poisson
+#' distribution (only used for `method = "Carter_etal_2018"`). Values that
+#' have a Poisson probability below the threshold are replaced by the average
+#' over the four neighbouring values.
 #'
-#' **`smooth_RLum`**
+#' @references
+#' Carter, J., Cresswell, A.J., Kinnaird, T.C., Carmichael, L.A., Murphy, S. &
+#' Sanderson, D.C.W., 2018. Non-Poisson variations in photomultipliers and
+#' implications for luminescence dating. Radiation Measurements 120, 267-273.
+#' \doi{10.1016/j.radmeas.2018.05.010}
 #'
-#' Same object as input, after smoothing
-#'
-#' @md
 #' @export
 setMethod(
   f = "smooth_RLum",
   signature = "RLum.Data.Curve",
-    function(object, k = NULL, fill = NA, align = "right", method = "mean") {
+  function(object, k = NULL, fill = NA, align = "right", method = "mean",
+           p_acceptance = 1e-7) {
 
         object@data[,2] <- .smoothing(
           x = object@data[,2],
           k = k,
           fill = fill,
           align = align,
+          p_acceptance = p_acceptance,
           method = method)
 
         ##return via set function to get a new id
         set_RLum(class = "RLum.Data.Curve",
                  originator = "smooth_RLum",
                  data = object)
-
     }
  )
 
+## melt_RLum() --------------------------------------------------------------
+#' @describeIn melt_RLum
+#' Melts [RLum.Data.Curve-class] objects into a flat data.frame with columns
+#' `X`, `Y`, `TYPE`, `UID`, to be used in combination with other packages
+#' such as `ggplot2`.
+#'
+#' @export
+setMethod(
+  f = "melt_RLum",
+  signature = "RLum.Data.Curve",
+  function(object) {
+    data.frame(
+      X = object@data[,1],
+      Y = object@data[,2],
+      TYPE = object@recordType,
+      UID = object@.uid)
+  }
+)
