@@ -1,17 +1,15 @@
-#' @include get_RLum.R set_RLum.R names_RLum.R
-NULL
-
 #' Class `"RLum.Data.Image"`
 #'
-#' Class for representing luminescence image data (TL/OSL/RF). Such data are for example produced
-#' by the function [read_SPE2R]
+#' Class for representing luminescence image data (TL/OSL/RF). Such data are
+#' for example produced by function [read_SPE2R].
 #'
 #' @name RLum.Data.Image-class
 #'
 #' @docType class
 #'
 #' @slot recordType
-#' Object of class [character] containing the type of the curve (e.g. "OSL image", "TL image")
+#' Object of class [character] containing the type of the curve (e.g.
+#' "OSL image", "TL image").
 #'
 #' @slot curveType
 #' Object of class [character] containing curve type, allowed values
@@ -46,7 +44,6 @@ NULL
 #' ##create empty RLum.Data.Image object
 #' set_RLum(class = "RLum.Data.Image")
 #'
-#' @md
 #' @export
 setClass(
   "RLum.Data.Image",
@@ -65,7 +62,7 @@ setClass(
   )
 )
 
-# as() ----------------------------------------------------------------------------------------
+## as() ---------------------------------------------------------------------
 ##DATA.FRAME
 ##COERCE RLum.Data.Image >> data.frame AND data.frame >> RLum.Data.Image
 #' as()
@@ -80,7 +77,6 @@ setClass(
 #'   `matrix` \tab `matrix`
 #' }
 #'
-#' @md
 #' @name as
 ## from data.frame ----
 setAs("data.frame", "RLum.Data.Image",
@@ -101,7 +97,6 @@ setAs("RLum.Data.Image", "data.frame",
           } else {
             stop("No viable coercion to data.frame, object contains multiple frames.",
                  call. = FALSE)
-
           }
         })
 
@@ -123,7 +118,6 @@ setAs("RLum.Data.Image", "matrix",
           from@data[,,1, drop = TRUE]
         } else {
          stop("No viable coercion to matrix, object contains multiple frames. Please convert to array instead.", call. = FALSE)
-
         }
       })
 
@@ -135,7 +129,6 @@ setAs("array", "RLum.Data.Image",
             curveType = "NA",
             data = from,
             info = list())
-
       })
 
 ## to array ----
@@ -146,31 +139,31 @@ setAs("RLum.Data.Image", "array",
 ## from list ----
 setAs("list", "RLum.Data.Image",
       function(from, to){
-        array_list <- lapply(from, function(x) array(unlist(as.vector(x)), c(nrow(x), ncol(x), 1)))
+        if (length(from) == 0)
+          return(set_RLum("RLum.Data.Image"))
 
+        array_list <- lapply(from, function(x) array(unlist(as.vector(x)), c(nrow(x), ncol(x), 1)))
         new(to,
             recordType = "unknown curve type",
             curveType = "NA",
             data = array(unlist(array_list),
                          c(nrow(array_list[[1]]), ncol(array_list[[1]]), length(array_list))),
             info = list())
-
       })
 
 ## to list ----
 setAs("RLum.Data.Image", "list",
       function(from){
-       lapply(1:dim(from@data)[3], function(x) from@data[,,x])
+        num.images <- dim(from@data)[3]
+        if (is.na(num.images))
+          return(list())
+        lapply(1:num.images, function(x) from@data[,,x])
+      })
 
-    })
-
-# show() --------------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Image
-#' Show structure of `RLum.Data.Image` object
+## show() -------------------------------------------------------------------
+#' @describeIn show
+#' Show the structure of `RLum.Data.Image` objects.
 #'
-#' @keywords internal
-#'
-#' @md
 #' @export
 setMethod("show",
           signature(object = "RLum.Data.Image"),
@@ -190,49 +183,15 @@ setMethod("show",
             cat("\n\t .. .. full pixel value range:", paste(format(range(object@data), scientific = TRUE, digits = 2), collapse=" : "))
             cat("\n\t additional info elements:", length(object@info))
             #cat("\n\t\t >> names:", names(object@info))
+            cat("\n")
           }
 )
 
 
-
-# set_RLum() ----------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Image
-#' Construction method for RLum.Data.Image object. The slot info is optional
-#' and predefined as empty list by default.
+## set_RLum() ---------------------------------------------------------------
+#' @describeIn set_RLum
+#' Construction method for [RLum.Data.Image-class] objects.
 #'
-#' @param class [`set_RLum`]; [character]: name of the `RLum` class to create
-#'
-#' @param originator [`set_RLum`]; [character] (*automatic*):
-#' contains the name of the calling function (the function that produces this object);
-#' can be set manually.
-#'
-#' @param .uid [`set_RLum`]; [character] (*automatic*):
-#' sets an unique ID for this object using the internal C++ function `create_UID`.
-#'
-#' @param .pid [`set_RLum`]; [character] (*with default*):
-#' option to provide a parent id for nesting at will.
-#'
-#' @param recordType [`set_RLum`]; [character]:
-#' record type (e.g. "OSL")
-#'
-#' @param curveType [`set_RLum`]; [character]:
-#' curve type (e.g. "predefined" or "measured")
-#'
-#' @param data [`set_RLum`]; [matrix]:
-#' raw curve data. If data is of type `RLum.Data.Image` this can be used to
-#' re-construct the object, i.e. modified parameters except `.uid` and `.pid`. The rest
-#' will be subject to copy and paste unless provided.
-#'
-#' @param info [`set_RLum`]; [list]:
-#' info elements
-#'
-#' @return
-#'
-#' **`set_RLum`**
-#'
-#' Returns an object from class `RLum.Data.Image`
-#'
-#' @md
 #' @export
 setMethod(
   "set_RLum",
@@ -249,7 +208,7 @@ setMethod(
 
     ##The case where an RLum.Data.Image object can be provided
     ##with this RLum.Data.Image objects can be provided to be reconstructed
-    if (is(data, "RLum.Data.Image")) {
+    if (inherits(data, "RLum.Data.Image")) {
       ##check for missing curveType
       if (missing(curveType))
         curveType <- data@curveType
@@ -297,45 +256,27 @@ setMethod(
   }
 )
 
-# get_RLum() ----------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Image
-#' Accessor method for `RLum.Data.Image` object. The argument `info.object` is
-#' optional to directly access the info elements. If no info element name is
-#' provided, the raw image data (`array`) will be returned.
+## get_RLum() ---------------------------------------------------------------
+#' @describeIn get_RLum
+#' Accessor method for [RLum.Data.Image-class] objects.
+#' The argument `info.object` is optional to directly access the info elements.
+#' If no info element name is provided, the raw image data (`array`) will be
+#' returned.
 #'
-#' @param object [`get_RLum`], [`names_RLum`] (**required**):
-#' an object of class [RLum.Data.Image-class]
-#'
-#' @param info.object [`get_RLum`]; [character]:
-#' name of the info object to returned
-#'
-#' @return
-#'
-#' **`get_RLum`**
-#'
-#' 1. Returns the data object ([array])
-#' 2. only the info object if `info.object` was set.
-#'
-#' @md
 #' @export
 setMethod("get_RLum",
           signature("RLum.Data.Image"),
-          definition = function(object, info.object) {
-
-            ##if missing info.object just show the curve values
-            if(!missing(info.object)){
-              if(!inherits(info.object, "character"))
-                stop("[get_RLum] 'info.object' has to be a character!", call. = FALSE)
+          definition = function(object, info.object = NULL) {
+            .set_function_name("get_RLum")
+            on.exit(.unset_function_name(), add = TRUE)
 
+            .validate_class(info.object, "character", null.ok = TRUE)
+            if (!is.null(info.object)) {
               if(info.object %in% names(object@info)){
                 unlist(object@info[info.object])
-
               } else {
-                stop(paste0(
-                  "[get_RLum] Invalid element name. Valid names are: ",
-                  paste(names(object@info), collapse = ", ")
-                ),
-                call. = FALSE)
+                .throw_error("Invalid element name, valid names are: ",
+                             .collapse(names(object@info)))
              }
             } else {
               object@data
@@ -343,21 +284,12 @@ setMethod("get_RLum",
           })
 
 
-
 # names_RLum() --------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Image
-#' Returns the names info elements coming along with this curve object
+#' @describeIn names_RLum
+#' Returns the names of the info elements stored in the object.
 #'
-#' @return
-#'
-#' **`names_RLum`**
-#'
-#' Returns the names of the info elements
-#'
-#' @md
 #' @export
 setMethod(
   "names_RLum",
   "RLum.Data.Image",
   function(object) names(object@info))
-
