@@ -1,6 +1,3 @@
-#' @include get_RLum.R set_RLum.R names_RLum.R bin_RLum.Data.R
-NULL
-
 #' Class `"RLum.Data.Spectrum"`
 #'
 #' Class for representing luminescence spectra data (TL/OSL/RF).
@@ -13,7 +10,8 @@ NULL
 #' Object of class [character] containing the type of the curve (e.g. "TL" or "OSL")
 #'
 #' @slot curveType
-#' Object of class [character] containing curve type, allowed values are measured or predefined
+#' Object of class [character] containing curve type, allowed values are
+#' "measured" or "predefined"
 #'
 #' @slot data
 #' Object of class [matrix] containing spectrum (count) values.
@@ -33,7 +31,7 @@ NULL
 #' @section Class version: 0.5.2
 #'
 #' @author
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystywyth University (United Kingdom)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [RLum-class], [RLum.Data-class], [plot_RLum]
 #'
@@ -55,7 +53,6 @@ NULL
 #' plot_RLum(TL.Spectrum)
 #' }
 #'
-#' @md
 #' @export
 setClass(
   "RLum.Data.Spectrum",
@@ -75,25 +72,22 @@ setClass(
 )
 
 
-
-# as() -----------------------------------------------------------------------------------------
+## as() ---------------------------------------------------------------------
 ##data.frame
 ##COERCE RLum.Data.Spectrum >> data.frame AND data.frame >> RLum.Data.Spectrum
 #' as()
 #'
 #' for `[RLum.Data.Spectrum-class]`
 #'
-#'
 #' **[RLum.Data.Spectrum-class]**
 #'
-#' \tabular{ll}{
+#' \tabular{lll}{
 #'   **from** \tab **to**\cr
 #'   `data.frame` \tab `data.frame`\cr
 #'   `matrix` \tab `matrix`
+#'   `list` \tab `list`
 #' }
 #'
-#'
-#' @md
 #' @name as
 setAs("data.frame", "RLum.Data.Spectrum",
       function(from,to){
@@ -108,10 +102,8 @@ setAs("data.frame", "RLum.Data.Spectrum",
 setAs("RLum.Data.Spectrum", "data.frame",
       function(from){
         as.data.frame(from@data)
-
       })
 
-
 ##MATRIX
 ##COERCE RLum.Data.Spectrum >> matrix AND matrix >> RLum.Data.Spectrum
 setAs("matrix", "RLum.Data.Spectrum",
@@ -126,16 +118,30 @@ setAs("matrix", "RLum.Data.Spectrum",
 setAs("RLum.Data.Spectrum", "matrix",
       function(from){
         from@data
-
       })
 
-# show() -------------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Spectrum
-#' Show structure of `RLum.Data.Spectrum` object
+## LIST
+## COERCE RLum.Data.Spectrum >> list AND list >> RLum.Data.Spectrum
+setAs("list", "RLum.Data.Spectrum",
+      function(from, to){
+        if (length(from) == 0)
+          return(set_RLum("RLum.Data.Spectrum"))
+        new(to,
+            recordType = NA_character_,
+            curveType = NA_character_,
+            data = matrix(unlist(from)),
+            info = list())
+      })
+
+setAs("RLum.Data.Spectrum", "list",
+      function(from){
+        apply(from@data, 2, list)
+      })
+
+## show() -------------------------------------------------------------------
+#' @describeIn show
+#' Show the structure of `RLum.Data.Spectrum` objects.
 #'
-#' @keywords internal
-#'
-#' @md
 #' @export
 setMethod("show",
           signature(object = "RLum.Data.Spectrum"),
@@ -157,50 +163,15 @@ setMethod("show",
             cat("\n\t .. .. range count values:", z.range)
             cat("\n\t additional info elements:", length(object@info))
             #cat("\n\t\t >> names:", names(object@info))
+            cat("\n")
           }
 )
 
 
-
-# set_RLum() ----------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Spectrum
-#' Construction method for RLum.Data.Spectrum object. The slot info is optional
-#' and predefined as empty list by default
+## set_RLum() ---------------------------------------------------------------
+#' @describeIn set_RLum
+#' Construction method for [RLum.Data.Spectrum-class] objects.
 #'
-#' @param class [`set_RLum`]; [character] (*automatic*):
-#' name of the `RLum` class to create.
-#'
-#' @param originator [character] (*automatic*):
-#' contains the name of the calling function (the function that produces this object);
-#' can be set manually.
-#'
-#' @param .uid [`set_RLum`]; [character] (*automatic*):
-#' sets an unique ID for this object using the internal C++ function `create_UID`.
-#'
-#' @param .pid [`set_RLum`]; [character] (*with default*):
-#' option to provide a parent id for nesting at will.
-#'
-#' @param recordType [`set_RLum`]; [character]:
-#' record type (e.g. "OSL")
-#'
-#' @param curveType [`set_RLum`]; [character]:
-#' curve type (e.g. "predefined" or "measured")
-#'
-#' @param data [`set_RLum`]; [matrix]:
-#' raw curve data. If data is of type `RLum.Data.Spectrum`, this can be used
-#' to re-construct the object. If the object is reconstructed, `.uid`, `.pid` and `orginator`
-#' are always taken from the input object
-#'
-#' @param info [`set_RLum`] [list]:
-#' info elements
-#'
-#' @return
-#'
-#' **`[set_RLum]`**
-#'
-#' An object from the class `RLum.Data.Spectrum`
-#'
-#' @md
 #' @export
 setMethod(
   "set_RLum",
@@ -218,7 +189,7 @@ setMethod(
     ##The case where an RLum.Data.Spectrum object can be provided
     ##with this RLum.Data.Spectrum objects can be provided to be reconstructed
 
-    if (is(data, "RLum.Data.Spectrum")) {
+    if (inherits(data, "RLum.Data.Spectrum")) {
       ##check for missing curveType
       if (missing(curveType))
         curveType <- data@curveType
@@ -227,14 +198,12 @@ setMethod(
       if (missing(recordType))
         recordType <- data@recordType
 
-
       ##check for missing data ... not possible as data is the object itself
 
       ##check for missing info
       if (missing(info))
         info <- data@info
 
-
       ##check for missing .uid and .pid >> this are always taken from the
       ##original dataset
 
@@ -250,7 +219,6 @@ setMethod(
       newRLumDataSpectrum@.uid = data@.uid
       newRLumDataSpectrum@.pid = data@.pid
 
-
     } else {
       ##set empty class from object
       newRLumDataSpectrum <- new("RLum.Data.Spectrum")
@@ -263,119 +231,82 @@ setMethod(
       newRLumDataSpectrum@info = info
       newRLumDataSpectrum@.uid = .uid
       newRLumDataSpectrum@.pid = .pid
-
     }
 
     return(newRLumDataSpectrum)
-
   }
 )
 
 
-
-# get_RLum() ----------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Spectrum
-#' Accessor method for RLum.Data.Spectrum object. The argument info.object
-#' is optional to directly access the info elements. If no info element name
-#' is provided, the raw curve data (matrix) will be returned
+## get_RLum() ---------------------------------------------------------------
+#' @describeIn get_RLum
+#' Accessor method for [RLum.Data.Spectrum-class] objects.
+#' The argument `info.object` is optional to directly access the info elements.
+#' If no info element name is provided, the raw curve data (matrix) will be
+#' returned.
 #'
-#' @param object [`get_RLum`], [`names_RLum`] (**required**):
-#' an object of class [RLum.Data.Spectrum-class]
-#'
-#' @param info.object [`get_RLum`]; [character] (*optional*):
-#' the name of the info object to be called
-#'
-#' @return
-#'
-#' **`[get_RLum]`**
-#'
-#' 1. A [matrix] with the spectrum values or
-#' 2. only the info object if `info.object` was set.
-#'
-#' @md
 #' @export
 setMethod("get_RLum",
           signature("RLum.Data.Spectrum"),
-          definition = function(object, info.object) {
-            ##if missing info.object just show the curve values
+          definition = function(object, info.object = NULL) {
+              .set_function_name("get_RLum")
+              on.exit(.unset_function_name(), add = TRUE)
 
-            if (missing(info.object) == FALSE){
-              if(is(info.object, "character") == FALSE)
-                stop("[get_RLum] 'info.object' has to be a character!", call. = FALSE)
-
-
-              if (info.object %in% names(object@info) == TRUE){
+              .validate_class(info.object, "character", null.ok = TRUE)
+              if (!is.null(info.object)) {
+                if (!info.object %in% names(object@info)) {
+                  .throw_error("Invalid element name, valid names are: ",
+                               .collapse(names(object@info)))
+                }
                 unlist(object@info[info.object])
-
               } else {
-                stop(paste0(
-                  "[get_RLum] Invalid element name. Valid names are: ",
-                  paste(names(object@info), collapse = ", ")
-                ),
-                call. = FALSE)
-
+                ## info.object not provided, return the curve data
+                object@data
               }
-            } else {
-              object@data
-
-            }
           })
 
 
-
-# names() -------------------------------------------------------------------------------------
-#' @describeIn RLum.Data.Spectrum
-#' Returns the names info elements coming along with this curve object
+## names_RLum ---------------------------------------------------------------
+#' @describeIn names_RLum
+#' Returns the names of the info elements stored in the object.
 #'
-#' @return
-#'
-#' **`[names_RLum]`**
-#'
-#' The names of the info objects
-#'
-#' @md
 #' @export
 setMethod("names_RLum",
           "RLum.Data.Spectrum",
           function(object){
             names(object@info)
-
           })
 
 
-
-# bin_RLum() ----------------------------------------------------------------------------------#
-#' @describeIn RLum.Data.Spectrum
-#' Allows binning of RLum.Data.Spectrum data. Count values and values on the x-axis are summed-up;
-#' for wavelength/energy values the mean is calculated.
+## bin_RLum() ---------------------------------------------------------------
+#' @describeIn bin_RLum.Data
+#' Allows binning of RLum.Data.Spectrum data. Count values and values on the
+#' x-axis are summed up; for wavelength/energy values, the mean is calculated.
 #'
 #' @param bin_size.col [integer] (*with default*):
-#' set number of channels used for each bin, e.g. `bin_size.col = 2` means that
+#' number of channels used for each bin, e.g. `bin_size.col = 2` means that
 #' two channels are binned. Note: The function does not check the input, very large values
 #' mean a full column binning (a single sum)
 #'
 #' @param bin_size.row [integer] (*with default*):
-#' set number of channels used for each bin, e.g. `bin_size.row = 2` means that
+#' number of channels used for each bin, e.g. `bin_size.row = 2` means that
 #' two channels are binned. Note: The function does not check the input, very large values
 #' mean a full row binning (a single sum)
 #'
-#' @return
-#'
-#' **`[bin_RLum.Data]`**
-#'
-#' Same object as input, after applying the binning.
-#'
-#' @md
 #' @export
 setMethod(f = "bin_RLum.Data",
           signature = "RLum.Data.Spectrum",
           function(object, bin_size.col = 1, bin_size.row = 1) {
+            .set_function_name("bin_RLum.Data.Spectrum")
+            on.exit(.unset_function_name(), add = TRUE)
 
-            ##makee sure that we have no input problems
-            if (class(bin_size.col) != "numeric" || class(bin_size.row) != "numeric"){
-              stop("[bin_RLum.Data()] 'bin_size.row' and 'bin_size.col' must be of class 'numeric'!",
-                   call. = FALSE)
+            ## Integrity checks ---------------------------------------------
+
+            if (length(object@data) < 2) {
+              .throw_error("'object' contains no data")
             }
+            .validate_class(bin_size.row, c("numeric", "integer"))
+            .validate_class(bin_size.col, c("numeric", "integer"))
 
             ##make sure that we do not get in trouble with negative values
             bin_size.col <- abs(bin_size.col)
@@ -402,4 +333,3 @@ setMethod(f = "bin_RLum.Data",
             ##return object
             return(object)
           })
-
