@@ -57,7 +57,6 @@
 #' ##convert one record
 #' Risoe.BINfileData2RLum.Data.Curve(CWOSL.SAR.Data, id = 1)
 #'
-#' @md
 #' @noRd
 .Risoe.BINfileData2RLum.Data.Curve <- function(
   object,
@@ -76,15 +75,13 @@
   # grep id of record -------------------------------------------------------
   ##if id is set, no input for pos and run is necessary
   if (missing(id)) {
-    id <- METADATA[METADATA[["POSITION"]] == pos &
-                     METADATA[["SET"]] == set &
-                     METADATA[["RUN"]] == run,
-                   "ID"]
-
+    id <- METADATA$ID[METADATA[["POSITION"]] == pos &
+                      METADATA[["SET"]] == set &
+                      METADATA[["RUN"]] == run]
   }
 
   ##grep info elements
-  info <- lapply(1:length(names(METADATA)), function(x){METADATA[[x]][id]})
+  info <- lapply(METADATA, function(x) x[id])
   names(info) <- names(METADATA)
 
   # Build object ------------------------------------------------------------
@@ -102,9 +99,7 @@
       TOLDELAY = METADATA[["TOLDELAY"]][id],
       TOLON = METADATA[["TOLON"]][id],
       TOLOFF = METADATA[["TOLOFF"]][id]
-
     ),
     info = info
   )
-
 }
