@@ -1,26 +1,29 @@
 #' @title Analyse SAR CW-OSL Measurements
 #'
-#' @description The function performs a SAR CW-OSL analysis on an
-#' [RLum.Analysis-class] object including growth curve fitting.
+#' @description
+#' The function performs a SAR CW-OSL analysis on an [RLum.Analysis-class]
+#' object, including growth curve fitting.
 #'
 #' @details
 #' The function performs an analysis for a standard SAR protocol measurements
 #' introduced by Murray and Wintle (2000) with CW-OSL curves. For the
 #' calculation of the `Lx/Tx` value the function [calc_OSLLxTxRatio] is
-#' used. For **changing the way the Lx/Tx error is calculated** use the argument
+#' used. To **change the way the Lx/Tx error is calculated** use the arguments
 #' `background.count.distribution` and `sigmab`, which will be passed to the function
 #' [calc_OSLLxTxRatio].
 #'
 #' **What is part of a SAR sequence?**
 #'
-#' The function is rather picky when it comes down to accepted curve input (OSL,IRSL,...) and structure.
-#' A SAR sequence is basically a set of \eqn{L_{x}/T_{x}} curves. Hence, every 2nd curve
-#' is considered a shine-down curve related to the test dose. It also means that the number of
-#' curves for \eqn{L_{x}} has to be equal to the number of \eqn{T_{x}} curves, and that
-#' hot-bleach curves **do not** belong into a SAR sequence; at least not for the analysis.
-#' Other curves allowed and processed are preheat curves, or preheat curves measured as TL, and
-#' irradiation curves. The later one indicates the duration of the irradiation, the
-#' dose and test dose points, e.g., as part of XSYG files.
+#' The function is rather picky when it comes down to accepted curve input
+#' (OSL, IRSL,...) and structure. A SAR sequence is basically a set of
+#' \eqn{L_{x}/T_{x}} curves. Hence, every second curve is considered a
+#' shine-down curve related to the test dose. It also means that the number of
+#' curves for \eqn{L_{x}} has to be equal to the number of \eqn{T_{x}} curves,
+#' and that hot-bleach curves **do not** belong into a SAR sequence; at least
+#' not for the analysis. Other curves allowed and processed are preheat curves,
+#' or preheat curves measured as TL, and irradiation curves. The later one
+#' indicates the duration of the irradiation, the dose and test dose points,
+#' e.g., as part of XSYG files.
 #'
 #' **Argument `object` is of type `list`**
 #'
@@ -34,8 +37,9 @@
 #' otherwise the function will create an own list of the requested length.
 #' Function output will be just one single [RLum.Results-class] object.
 #'
-#' Please be careful when using this option. It may allow a fast an efficient data analysis, but
-#' the function may also break with an unclear error message, due to wrong input data.
+#' Please be careful when using this option. While it may allow for a fast and
+#' efficient data analysis, the function may break with an unclear error
+#' message if the input data is misspecified.
 #'
 #' **Working with IRSL data**
 #'
@@ -48,23 +52,24 @@
 #' have to be pre-selected by the user to fit the standards of the SAR
 #' protocol, i.e., Lx,Tx,Lx,Tx and so on.
 #'
-#' Example: Imagine the measurement contains `pIRIR50` and `pIRIR225` IRSL curves.
-#' Only one curve type can be analysed at the same time: The `pIRIR50` curves or
-#' the `pIRIR225` curves.
+#' Example: Imagine the measurement contains `pIRIR50` and `pIRIR225` IRSL
+#' curves. Only one curve type can be analysed at the same time: either the
+#' `pIRIR50` curves or the `pIRIR225` curves.
 #'
 #' **Supported rejection criteria**
 #'
 #' `[recycling.ratio]`: calculated for every repeated regeneration dose point.
 #'
 #' `[recuperation.rate]`: recuperation rate calculated by comparing the
-#' `Lx/Tx` values of the zero regeneration point with the `Ln/Tn` value (the `Lx/Tx`
-#' ratio of the natural signal). For methodological background see Aitken and
-#' Smith (1988). As a variant with the argument `recuperation_reference` another dose point can be
-#' selected as reference instead of `Ln/Tn`.
+#' `Lx/Tx` values of the zero regeneration point with the `Ln/Tn` value (the
+#' `Lx/Tx` ratio of the natural signal). For methodological background see
+#' Aitken and Smith (1988). As a variant, `recuperation_reference` can be
+#' specified to select another dose point as reference instead of `Ln/Tn`.
 #'
-#' `[testdose.error]`: set the allowed error for the test dose, which per
-#' default should not exceed 10%. The test dose error is calculated as `Tx_net.error/Tx_net`.
-#' The calculation of the \eqn{T_{n}} error is detailed in [calc_OSLLxTxRatio].
+#' `[testdose.error]`: set the allowed error for the test dose, which by
+#' default should not exceed 10%. The test dose error is calculated as
+#' `Tx_net.error/Tx_net`. The calculation of the \eqn{T_{n}} error is detailed
+#' in [calc_OSLLxTxRatio].
 #'
 #' `[palaeodose.error]`: set the allowed error for the De value, which per
 #' default should not exceed 10%.
@@ -72,47 +77,49 @@
 #' **Irradiation times**
 #'
 #' The function makes two attempts to extra irradiation data (dose points)
-#' automatically from the input object, if the argument `dose.points` was not
+#' automatically from the input object, if the argument `dose.points` is not
 #' set (aka set to `NULL`).
 #'
-#' 1. It searches in every curve for an info object called `IRR_TIME`. If this was set, any value
-#' set here is taken as dose point.
+#' 1. It searches in every curve for an info object called `IRR_TIME`. If this
+#' is found, any value set there is taken as dose point.
 #'
-#' 2. If the object contains curves of type `irradiation`, the function tries to
-#' use this information to assign these values to the curves. However, the function
-#' does **not** overwrite values preset in `IRR_TIME`.
+#' 2. If the object contains curves of type `irradiation`, the function tries
+#' to use this information to assign these values to the curves. However, the
+#' function does **not** overwrite values preset in `IRR_TIME`.
 #'
 #' @param object [RLum.Analysis-class] (**required**):
 #' input object containing data for analysis, alternatively a [list] of
-#' [RLum.Analysis-class] objects can be provided. The object should contain **only** curves
-#' considered part of the SAR protocol (see Details).
+#' [RLum.Analysis-class] objects can be provided. The object should **only**
+#' contain curves considered part of the SAR protocol (see Details).
 #'
 #' @param signal.integral.min [integer] (**required**):
-#' lower bound of the signal integral. Can be a [list] of [integer]s, if `object` is
-#' of type [list]. If the input is vector (e.g., `c(1,2)`) the 2nd value will be interpreted
-#' as the minimum signal integral for the `Tx` curve. Can be set to `NA`, in this
-#' case no integrals are taken into account.
+#' lower bound of the signal integral. It can be a [list] of integers, if
+#' `object` is a list. If the input is a vector (e.g., `c(1,2)`), the second
+#' value will be interpreted as the minimum signal integral for the `Tx` curve.
+#' It can be set to `NA`, in which case no integrals are taken into account.
 #'
 #' @param signal.integral.max [integer] (**required**):
-#' upper bound of the signal integral. Can be a [list] of [integer]s, if `object` is
-#' of type [list]. If the input is vector (e.g., `c(1,2)`) the 2nd value will be interpreted
-#' as the maximum signal integral for the `Tx` curve. Can be set to `NA`, in this
-#' case no integrals are taken into account.
+#' upper bound of the signal integral. It can be a [list] of integers if
+#' `object` is a list. If the input is a vector (e.g., `c(1,2)`), the second
+#' value will be interpreted as the maximum signal integral for the `Tx` curve.
+#' It can be set to `NA`, in which case no integrals are taken into account.
 #'
 #' @param background.integral.min [integer] (**required**):
-#' lower bound of the background integral. Can be a [list] of [integer]s, if `object` is
-#' of type [list]. If the input is vector (e.g., `c(1,2)`) the 2nd value will be interpreted
-#' as the minimum background integral for the `Tx` curve. Can be set to `NA`, in this
-#' case no integrals are taken into account.
+#' lower bound of the background integral. It can be a [list] of integers if
+#' `object` is a list. If the input is a vector (e.g., `c(1,2)`), the second
+#' value will be interpreted as the minimum background integral for the `Tx`
+#' curve. It can be set to `NA`, in which case no integrals are taken into
+#' account.
 #'
 #' @param background.integral.max [integer] (**required**):
-#' upper bound of the background integral. Can be a [list] of [integer]s, if `object` is
-#' of type [list]. If the input is vector (e.g., `c(1,2)`) the 2nd value will be interpreted
-#' as the maximum background integral for the `Tx` curve. Can be set to `NA`, in this
-#' case no integrals are taken into account.
+#' upper bound of the background integral. It can be a [list] of integers if
+#' `object` is a list. If the input is a vector (e.g., `c(1,2)`), the second
+#' value will be interpreted as the maximum background integral for the `Tx`
+#' curve. It can be set to `NA`, in which case no integrals are taken into
+#' account.
 #'
-#' @param OSL.component [character] or [integer] (*optional*): s single index
-#' or a [character] defining the signal component to be evaluated.
+#' @param OSL.component [character] or [integer] (*optional*):
+#' single index or a [character] defining the signal component to be evaluated.
 #' It requires that the object was processed by `OSLdecomposition::RLum.OSL_decomposition`.
 #' This argument can either be the name of the OSL component assigned by
 #' `OSLdecomposition::RLum.OSL_global_fitting` or the index in the descending
@@ -130,25 +137,27 @@
 #'
 #' Allowed arguments are `recycling.ratio`, `recuperation.rate`,
 #' `palaeodose.error`, `testdose.error`, `exceed.max.regpoint = TRUE/FALSE`,
-#' `recuperation_reference = "Natural"` (or any other dose point, e.g., `"R1"`).
+#' `recuperation_reference` ("Natural" or any other dose point, e.g., `"R1"`).
 #' Example: `rejection.criteria = list(recycling.ratio = 10)`.
-#' Per default all numerical values are set to 10, `exceed.max.regpoint = TRUE`.
-#' Every criterion can be set to `NA`. In this value are calculated, but not considered, i.e.
-#' the RC.Status becomes always `'OK'`
+#' By default, all numerical values are set to 10, `exceed.max.regpoint = TRUE`.
+#' Every criterion can be set to `NA`, in which case values are calculated, but
+#' they are not considered, i.e. their corresponding RC.Status is always `'OK'`.
 #'
 #' @param dose.points [numeric] (*optional*):
 #' a numeric vector containing the dose points values. Using this argument
 #' overwrites dose point values extracted from other data. Can be a [list] of
-#' [numeric] vectors, if `object` is of type [list]
+#' [numeric] vectors, if `object` is of type [list].
 #'
-#' @param dose.points.test [numeric] (*optional*): a numeric vector containing
-#' with the test dose in the same units as `dose.points`. If length = 1, the numbers
-#' will be recycled. Has only an effect for `fit.method = 'OTORX'`
+#' @param dose.points.test [numeric] (*optional*):
+#' a numeric vector containing the test dose in the same units as `dose.points`.
+#' If length = 1, the values will be recycled. It has only an effect for
+#' `fit.method = 'OTORX'`.
 #'
-#' @param trim_channels [logical] (*with default*): trim channels per record category
-#' to the lowest number of channels in the category by using [trim_RLum.Data].
-#' Applies only to `OSL` and `IRSL` curves. For a more granular control use [trim_RLum.Data]
-#' before passing the input object.
+#' @param trim_channels [logical] (*with default*):
+#' trim channels per record category to the lowest number of channels in the
+#' category by using [trim_RLum.Data]. Applies only to `OSL` and `IRSL` curves.
+#' For a more granular control use [trim_RLum.Data] before calling this
+#' function.
 #'
 #' @param mtext.outer [character] (*optional*):
 #' option to provide an outer margin `mtext`. Can be a [list] of [character]s,
@@ -191,19 +200,14 @@
 #'
 #' The output should be accessed using the function [get_RLum].
 #'
-#' @note
-#' This function must not be mixed up with the function
-#' [Analyse_SAR.OSLdata], which works with
-#' [Risoe.BINfileData-class] objects.
-#'
 #' **The function currently does support only 'OSL', 'IRSL' and 'POSL' data!**
 #'
 #' @section Function version: 0.11.0
 #'
 #' @author Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
-#' @seealso [calc_OSLLxTxRatio], [plot_GrowthCurve], [RLum.Analysis-class],
-#' [RLum.Results-class], [get_RLum], [fit_DoseResponseCurve], [plot_DoseResponseCurve]
+#' @seealso [calc_OSLLxTxRatio], [fit_DoseResponseCurve],
+#' [plot_DoseResponseCurve], [RLum.Analysis-class], [RLum.Results-class]
 #'
 #' @references
 #' Aitken, M.J. and Smith, B.W., 1988. Optical dating: recuperation
@@ -242,6 +246,7 @@
 #' background.integral.max = 1000,
 #' log = "x",
 #' fit.method = "EXP",
+#' plot_onePage = TRUE,
 #' rejection.criteria = list(
 #'   recycling.ratio = 10,
 #'   recuperation.rate = 10,
@@ -271,7 +276,6 @@
 #'  fit.method = "OTORX")
 #' }
 #'
-#' @md
 #' @export
 analyse_SAR.CWOSL<- function(
   object,
@@ -303,7 +307,6 @@ if(is.list(object)){
   ##handle main separately
   if("main"%in% names(list(...))){
     main <- .listify(list(...)$main, length = length(object))
-
   }else{
     main <- as.list(paste0("ALQ #",1:length(object)))
   }
@@ -329,9 +332,7 @@ if(is.list(object)){
       ...)
   })))
 
-
   ##return
-  ##DO NOT use invisible here, this will prevent the function from stopping
   if(length(results) == 0) return(NULL)
 
   ## add aliquot number
@@ -347,6 +348,7 @@ error.list <- list()
   ## Integrity checks -------------------------------------------------------
   .validate_class(object, "RLum.Analysis")
   .validate_class(plot_singlePanels, c("logical", "integer", "numeric"))
+  .validate_logical_scalar(onlyLxTxTable)
 
   ## trim OSL or IRSL channels
   if(trim_channels[1]) {
@@ -408,7 +410,7 @@ error.list <- list()
       }
 
     ##INTEGRAL LIMITS
-    if(!is(signal.integral, "integer") | !is(background.integral, "integer")){
+    if (!is.integer(signal.integral) || !is.integer(background.integral)) {
       .throw_error("'signal.integral' or 'background.integral' is not of type integer")
     }
   }
@@ -430,11 +432,12 @@ error.list <- list()
   CWcurve.type <- names(which.max(table(CWcurve.type)))
 
 # Rejection criteria ------------------------------------------------------
-  if(is.null(rejection.criteria) || class(rejection.criteria)[1] != "list")
+
+  if (class(rejection.criteria)[1] != "list")
     rejection.criteria <- list()
 
   ##set list
-    rejection.criteria <- modifyList(x = list(
+  rejection.criteria <- modifyList(x = list(
       recycling.ratio = 10,
       recuperation.rate = 10,
       palaeodose.error = 10,
@@ -443,26 +446,21 @@ error.list <- list()
       recuperation_reference = "Natural"
     ),
     val = rejection.criteria,
-  keep.null = TRUE)
+    keep.null = TRUE)
 
 
 # Deal with extra arguments ----------------------------------------------------
   ##deal with addition arguments
   extraArgs <- list(...)
 
-  main <- if("main" %in% names(extraArgs)) extraArgs$main else  ""
-  log <- if("log" %in% names(extraArgs)) extraArgs$log else ""
-  cex <- if("cex" %in% names(extraArgs)) extraArgs$cex else 1
+  main <- extraArgs$main %||% ""
+  log <- extraArgs$log %||% ""
+  cex <- extraArgs$cex %||% 1
 
   background.count.distribution <-
-    if ("background.count.distribution" %in% names(extraArgs)) {
-      extraArgs$background.count.distribution
-    } else  {
-      "non-poisson"
-    }
-
-  sigmab <- if("sigmab" %in% names(extraArgs)) extraArgs$sigmab else NULL
-  sig0 <- if("sig0" %in% names(extraArgs)) extraArgs$sig0 else 0
+      extraArgs$background.count.distribution %||% "non-poisson"
+  sigmab <- extraArgs$sigmab
+  sig0 <- extraArgs$sig0 %||% 0
 
   ## deprecated argument
   if ("plot.single" %in% names(extraArgs)) {
@@ -504,11 +502,11 @@ error.list <- list()
   }
 
   ##check if the curve lengths differ
-  temp.matrix.length <- unlist(sapply(1:length(object@records), function(x) {
-                          if(object@records[[x]]@recordType==CWcurve.type){
-                              length(object@records[[x]]@data[,1])
-                          }
-  }))
+  temp.matrix.length <- unlist(lapply(object@records,
+                                      function(x) {
+                                        if (x@recordType %in% CWcurve.type)
+                                          nrow(x@data)
+                                      }))
 
   if(length(unique(temp.matrix.length))!=1){
     error.list[[2]] <- paste0("Input curves have different lengths (",
@@ -623,13 +621,8 @@ error.list <- list()
             sig0 = sig0))
       }
 
-        ##grep dose
-        temp.Dose <- object@records[[OSL.Curves.ID[x]]]@info$IRR_TIME
-
-          ##for the case that no information on the dose can be found
-          if (is.null(temp.Dose)) temp.Dose <- NA
-
-          temp.LnLxTnTx <- cbind(Dose = temp.Dose, temp.LnLxTnTx)
+      temp.Dose <- object@records[[OSL.Curves.ID[x]]]@info$IRR_TIME %||% NA
+      temp.LnLxTnTx <- cbind(Dose = temp.Dose, temp.LnLxTnTx)
 
       }), silent = TRUE)
 
@@ -648,16 +641,15 @@ error.list <- list()
     ##overwrite dose point manually
     if (!is.null(dose.points) & length(dose.points) > 0) {
       if (length(dose.points) != length(LnLxTnTx$Dose))
-        .throw_error("Length of 'dose.points' differs from number of curves")
+        .throw_error("Length of 'dose.points' (", length(dose.points),
+                     ") differs from number of curves (", length(LnLxTnTx$Dose), ")")
 
       LnLxTnTx$Dose <- dose.points
     }
 
     ## set test dose points
-    if(!is.null(dose.points.test))
-      LnLxTnTx$Test_Dose <- rep(dose.points.test, length.out = nrow(LnLxTnTx))
-    else
-      LnLxTnTx$Test_Dose <- rep(-1, length.out = nrow(LnLxTnTx))
+    LnLxTnTx$Test_Dose <- rep(dose.points.test %||% -1,
+                              length.out = nrow(LnLxTnTx))
 
     ##check whether we have dose points at all
     if (is.null(dose.points) & anyNA(LnLxTnTx$Dose)) {
@@ -717,12 +709,12 @@ error.list <- list()
 
     ## Calculate Recuperation Rate ---------------------------------------------
     ## check for incorrect key words
-    if(any(!rejection.criteria$recuperation_reference[1] %in% LnLxTnTx[,"Name"]))
-      .throw_error("Recuperation reference invalid, valid are: ",
-                   .collapse(LnLxTnTx[, "Name"], quote = FALSE))
+    if (!rejection.criteria$recuperation_reference[1] %in% LnLxTnTx[, "Name"])
+      .throw_error("Recuperation reference invalid, valid values are: ",
+                   .collapse(LnLxTnTx[, "Name"]))
 
     ##Recuperation Rate (capable of handling multiple type of recuperation values)
-    if(any(LnLxTnTx$Name == "R0")) {
+    if ("R0" %in% LnLxTnTx$Name) {
       Recuperation <- vapply(seq_len(sum(LnLxTnTx$Name == "R0")), \(x) {
                  LnLxTnTx[LnLxTnTx[["Name"]] == "R0","LxTx"][x] /
                  LnLxTnTx[LnLxTnTx[["Name"]] == rejection.criteria$recuperation_reference[1],"LxTx"]
@@ -739,9 +731,8 @@ error.list <- list()
 
     # Evaluate and Combine Rejection Criteria ---------------------------------
     ## get name of the criteria
-    temp.criteria <- c(
-      if(!is.null(colnames(RecyclingRatio))) colnames(RecyclingRatio) else NA_character_,
-      if(!is.null(colnames(Recuperation))) colnames(Recuperation) else NA_character_)
+    temp.criteria <- c(colnames(RecyclingRatio) %||% NA_character_,
+                       colnames(Recuperation) %||% NA_character_)
 
     ## get value
     temp.value <- c(RecyclingRatio, Recuperation)
@@ -752,6 +743,13 @@ error.list <- list()
        rep(rejection.criteria$recycling.ratio, length(RecyclingRatio)),
        rep(rejection.criteria$recuperation.rate, length(Recuperation))) / 100
 
+    ## compare a single value with a threshold (either can be NA)
+    .status_from_threshold <- function(value, threshold) {
+      if (is.na(threshold) || isTRUE(value <= threshold))
+        return("OK")
+      return("FAILED")
+    }
+
     ##RecyclingRatio
     temp.status.RecyclingRatio <- rep("OK", length(RecyclingRatio))
     if (!anyNA(RecyclingRatio) && !is.na(rejection.criteria$recycling.ratio))
@@ -759,18 +757,11 @@ error.list <- list()
         rejection.criteria$recycling.ratio / 100)] <- "FAILED"
 
     ##Recuperation
-    temp.status.Recuperation <- "OK"
-    if (!is.na(Recuperation)[1] &
-        !is.na(rejection.criteria$recuperation.rate)) {
-      temp.status.Recuperation  <-
-        sapply(1:length(Recuperation), function(x) {
-          if (Recuperation[x] > rejection.criteria$recuperation.rate / 100) {
-            "FAILED"
-          } else{
-            "OK"
-          }
-        })
-    }
+    temp.status.Recuperation <- sapply(Recuperation, function(value) {
+      if (is.na(value))
+        return("OK")
+      .status_from_threshold(value, rejection.criteria$recuperation.rate / 100)
+    })
 
     # Provide Rejection Criteria for Testdose error --------------------------
     testdose.error.calculated <- (LnLxTnTx$Net_TnTx.Error/LnLxTnTx$Net_TnTx)[1]
@@ -778,28 +769,15 @@ error.list <- list()
     testdose.error.threshold <-
       rejection.criteria$testdose.error / 100
 
-    if (is.na(testdose.error.calculated)) {
-      testdose.error.status <- "FAILED"
-
-    }else{
-      testdose.error.status <- "OK"
-      if(!is.na(testdose.error.threshold)){
-        testdose.error.status <- ifelse(
-          testdose.error.calculated <= testdose.error.threshold,
-          "OK", "FAILED"
-        )
-      }
-    }
-
     testdose.error.data.frame <- data.frame(
       Criteria = "Testdose error",
       Value = testdose.error.calculated,
       Threshold = testdose.error.threshold,
-      Status =  testdose.error.status,
+      Status = .status_from_threshold(testdose.error.calculated,
+                                      testdose.error.threshold),
       stringsAsFactors = FALSE
     )
 
-
     RejectionCriteria <- data.frame(
       Criteria = temp.criteria,
       Value = temp.value,
@@ -888,10 +866,6 @@ error.list <- list()
                        length(col), " curves are plotted")
       }
 
-      ##legend text
-      legend.text <-
-        paste(LnLxTnTx$Name,"\n(",LnLxTnTx$Dose,")", sep = "")
-
       ##get channel resolution (should be equal for all curves)
       resolution.OSLCurves <- round(object@records[[OSL.Curves.ID[1]]]@data[2,1] -
                                       object@records[[OSL.Curves.ID[1]]]@data[1,1],
@@ -1000,7 +974,7 @@ error.list <- list()
             xlim = xlim_range,
             ylim = ylim_range,
             main = main,
-            log = if (log == "y" | log == "xy") "y" else "")
+            log = gsub("x", "", log))
 
           #provide curve information as mtext, to keep the space for the header
           mtext(
@@ -1067,8 +1041,9 @@ error.list <- list()
           cex = 4,
           ylim = c(0,10))
 
-        ##add text
-        text(x, y, legend.text, offset = 1, pos = 1)
+        ## add legend text
+        text(x, y, paste0(LnLxTnTx$Name, "\n(", LnLxTnTx$Dose, ")"),
+             offset = 1, pos = 1)
 
         ##add line
         abline(h = 10,lwd = 0.5)
@@ -1091,6 +1066,7 @@ error.list <- list()
     ##overall plot option selection for plot.single.sel
     plot <- if (plot[1] && 6 %in% plot.single.sel) TRUE else FALSE
 
+    ## this must be kept in sync with fit_DoseResponseCurve()
     temp.GC.all.na <- data.frame(
         De = NA,
         De.Error = NA,
@@ -1102,13 +1078,15 @@ error.list <- list()
         D63 = NA,
         n_N = NA,
         De.MC = NA,
-        De.plot = NA,
         Fit = NA,
+        Mode = NA,
         HPDI68_L = NA,
         HPDI68_U = NA,
         HPDI95_L = NA,
         HPDI95_U = NA,
         RC.Status = NA,
+        .De.plot = NA,
+        .De.raw = NA,
         stringsAsFactors = FALSE)
 
     ##Fit and plot growth curve
@@ -1116,27 +1094,24 @@ error.list <- list()
     temp.GC.fit.Formula <- NULL
 
   # Calculate Dose-response curve -------------------------------------------
-  if(!onlyLxTxTable){
+    if (!onlyLxTxTable) {
       temp.GC <- do.call(
         fit_DoseResponseCurve,
         args = c(list(object = temp.sample), list(...)))
 
-        ##if null
-        if(is.null(temp.GC)){
+      if (is.null(temp.GC)) {
           temp.GC <- temp.GC.all.na
           temp.GC.fit.Formula <- NA
 
           ##create empty plots if needed, otherwise subsequent functions may crash
           if(plot){
             shape::emptyplot()
-            if (!"output.plotExtended" %in% extraArgs ||
-                extraArgs$output.plotExtended) {
+            if (extraArgs$plot_extended %||% TRUE) {
               shape::emptyplot()
               shape::emptyplot()
             }
           }
-
-        }else{
+      } else {
           if(plot) {
             do.call(plot_DoseResponseCurve, args = modifyList(
               list(
@@ -1155,45 +1130,27 @@ error.list <- list()
           temp.GC <- get_RLum(temp.GC)
 
           # Provide Rejection Criteria for Palaeodose error --------------------------
-          if(is.na(temp.GC[,1])){
-            palaeodose.error.calculated <- NA
-
-          }else{
-            palaeodose.error.calculated <- round(temp.GC[,2] / temp.GC[,1], digits = 5)
+          palaeodose.error.calculated <- NA
+          De <- as.numeric(temp.GC[, 1])
+          if (!is.na(De)) {
+            palaeodose.error.calculated <- round(temp.GC[, 2] / De, digits = 5)
           }
 
           palaeodose.error.threshold <-
             rejection.criteria$palaeodose.error / 100
 
-          if (!is.na(palaeodose.error.threshold) && (is.na(palaeodose.error.calculated) ||
-              palaeodose.error.calculated > palaeodose.error.threshold)) {
-            palaeodose.error.status <- "FAILED"
-          } else {
-            palaeodose.error.status <- "OK"
-          }
-
           palaeodose.error.data.frame <- data.frame(
             Criteria = "Palaeodose error",
             Value = palaeodose.error.calculated,
             Threshold = palaeodose.error.threshold,
-            Status =  palaeodose.error.status,
+            Status = .status_from_threshold(palaeodose.error.calculated,
+                                            palaeodose.error.threshold),
             stringsAsFactors = FALSE
           )
 
-          ##add exceed.max.regpoint
-          if (!is.na(temp.GC[,1]) &
-              !is.na(rejection.criteria$exceed.max.regpoint) &&
-              rejection.criteria$exceed.max.regpoint) {
-            status.exceed.max.regpoint <-
-              ifelse(max(LnLxTnTx$Dose) < temp.GC[,1], "FAILED", "OK")
-
-          }else{
-            status.exceed.max.regpoint <- "OK"
-          }
-
           exceed.max.regpoint.data.frame <- data.frame(
             Criteria = "De > max. dose point",
-            Value = as.numeric(temp.GC[,1]),
+            Value = De,
             Threshold = if(is.na(rejection.criteria$exceed.max.regpoint)){
                 NA
               }else if(!rejection.criteria$exceed.max.regpoint){
@@ -1201,7 +1158,7 @@ error.list <- list()
               }else{
                 as.numeric(max(LnLxTnTx$Dose))
               },
-            Status =  status.exceed.max.regpoint
+            Status = .status_from_threshold(De, max(LnLxTnTx$Dose))
           )
 
           ##add to RejectionCriteria data.frame
@@ -1209,28 +1166,25 @@ error.list <- list()
                                      palaeodose.error.data.frame,
                                      exceed.max.regpoint.data.frame)
 
-
-        ##add rejection status
-        if (length(grep("FAILED",RejectionCriteria$Status)) > 0) {
-          temp.GC <- data.frame(temp.GC, RC.Status = "FAILED", stringsAsFactors = FALSE)
-
-        }else{
-          temp.GC <- data.frame(temp.GC, RC.Status = "OK", stringsAsFactors = FALSE)
-        }
-       }#endif for is.null
+          ## add rejection status
+          status <- if ("FAILED" %in% RejectionCriteria$Status) "FAILED" else "OK"
+          temp.GC <- data.frame(temp.GC,
+                                RC.Status = status,
+                                stringsAsFactors = FALSE)
+      }
     }
 
       ##add information on the integration limits
-      temp.GC.extended <-
+    temp.GC.extended <-
         data.frame(
           signal.range = paste(min(signal.integral),":",
                                max(signal.integral)),
           background.range = paste(min(background.integral),":",
                                    max(background.integral)),
-          signal.range.Tx = paste(min(ifelse(is.null(signal.integral.Tx),NA,signal.integral.Tx)),":",
-                                  max(ifelse(is.null(signal.integral.Tx),NA,signal.integral.Tx))),
-          background.range.Tx = paste(min(ifelse(is.null(background.integral.Tx), NA,background.integral.Tx)) ,":",
-                                      max(ifelse(is.null(background.integral.Tx), NA,background.integral.Tx))),
+          signal.range.Tx = paste(min(signal.integral.Tx %||% NA), ":",
+                                  max(signal.integral.Tx %||% NA)),
+          background.range.Tx = paste(min(background.integral.Tx %||% NA) , ":",
+                                      max(background.integral.Tx %||% NA)),
           stringsAsFactors = FALSE
         )
 
@@ -1243,8 +1197,7 @@ error.list <- list()
       chk <- grepl(pattern = "position", tolower(names(x@info)), fixed = TRUE)
       if (any(chk))
         return(x@info[chk])
-      else
-        return(NA)
+      return(NA)
     })))[1]
 
     ## get grain numbers
@@ -1252,8 +1205,7 @@ error.list <- list()
       chk <- grepl(pattern = "grain", tolower(names(x@info)), fixed = TRUE)
       if (any(chk))
         return(x@info[chk])
-      else
-        return(NA)
+      return(NA)
     })))[1]
 
     temp.results.final <- set_RLum(
@@ -1291,7 +1243,6 @@ error.list <- list()
             plot_RLum.Data.Curve(temp.IRSL[[length(temp.IRSL)]], par.local = FALSE)
             .throw_warning("Multiple IRSL curves detected (IRSL test), only the last one shown")
           }
-
         }else{
           plot(1, type="n", axes=F, xlab="", ylab="")
           text(x = c(1,1), y = c(1, 1), labels = "No IRSL curve detected!")
