@@ -66,7 +66,7 @@
 #' Ignored if `plot = FALSE`.
 #'
 #' @param ... further arguments that will be passed to
-#' [analyse_SAR.CWOSL] and [plot_GrowthCurve]. Furthermore, the
+#' [analyse_SAR.CWOSL] and [plot_DoseResponseCurve]. Furthermore, the
 #' arguments `main` (headers), `log` (IRSL curves), `cex` (control
 #' the size) and `mtext.outer` (additional text on the plot area) can be passed to influence the plotting. If the input
 #' is a list, `main` can be passed as [vector] or [list].
@@ -165,7 +165,6 @@
 #'   dev.off()
 #' }
 #'
-#' @md
 #' @export
 analyse_pIRIRSequence <- function(
   object,
@@ -281,10 +280,9 @@ analyse_pIRIRSequence <- function(
 
   ## Deal with extra arguments
   extraArgs <- list(...)
-  mtext.outer <- if ("mtext.outer" %in% names(extraArgs)) extraArgs$mtext.outer
-  main <- if ("main" %in% names(extraArgs)) extraArgs$main else "MEASUREMENT INFO"
-  log <- if ("log" %in% names(extraArgs)) extraArgs$log else ""
-  cex <- if ("cex" %in% names(extraArgs)) extraArgs$cex else 0.7
+  main <- extraArgs$main %||% "MEASUREMENT INFO"
+  log <- extraArgs$log %||% ""
+  cex <- extraArgs$cex %||% 0.7
 
   ## Enforce a minimum plot device size: this is necessary as otherwise users
   ## may experience "figure margins too large" errors when trying to draw all
