@@ -1,4 +1,4 @@
-#' @title Function to remove cosmic rays from an RLum.Data.Spectrum S4 class object
+#' @title Cosmic-ray removal and spectrum smoothing for RLum.Data.Spectrum objects
 #'
 #' @description
 #' The function provides several methods for cosmic-ray removal and spectrum
@@ -12,7 +12,7 @@
 #' This method applies the cosmic-ray removal algorithm described by Pych
 #' (2003). There are some differences with respect to the publication:
 #'
-#' - For interpolation between neighbouring values the median is used instead
+#' - For interpolation between neighbouring values, the median is used instead
 #' of the mean.
 #' - The number of breaks in the histogram is set to half the number of the
 #' input values.
@@ -29,7 +29,7 @@
 #' `"smooth_RLum"` \tab `k` \tab [numeric] \tab see [smooth_RLum]\cr
 #'  \tab `fill` \tab [numeric] \tab see [smooth_RLum]\cr
 #'  \tab `align` \tab [character] \tab see [smooth_RLum]\cr
-#'  \tab `method` \tab [character] \tab see [smooth_RLum]\cr
+#'  \tab `method_smooth_RLum` \tab [character] \tab see [smooth_RLum]\cr
 #'}
 #'
 #' **Best practice**
@@ -37,7 +37,7 @@
 #' There is no single silver-bullet strategy for cosmic-ray removal, as it depends
 #' on the characteristic of the detector and the chosen settings. For instance,
 #' high values for pixel binning will improve the light output, but also cause
-#' multiple pixels being affected by a single cosmic-ray. The same is valid for
+#' multiple pixels to be affected by a single cosmic ray. The same is valid for
 #' longer integration times. The best strategy is to combine methods and ensure
 #' that the spectrum is not distorted on a case-to-case basis.
 #'
@@ -46,10 +46,11 @@
 #' Different methods can be combined by applying the method repeatedly to the
 #' dataset (see example).
 #'
-#' @param object [RLum.Data.Spectrum-class] or [RLum.Analysis-class] (**required**): input
-#' object to be treated. This can be also provided as [list]. If an [RLum.Analysis-class] object
-#' is provided, only the [RLum.Data.Spectrum-class] objects are treated. Please note: this mixing of
-#' objects does not work for a list of `RLum.Data` objects.
+#' @param object [RLum.Data.Spectrum-class] or [RLum.Analysis-class] (**required**):
+#' input object to be treated, which can be also provided as [list]. If an
+#' [RLum.Analysis-class] object is provided, only its [RLum.Data.Spectrum-class]
+#' objects are treated. Please note: this mixing of objects does not work for
+#' a list of `RLum.Data` objects.
 #'
 #' @param method [character] (*with default*):
 #' Defines method that is applied for cosmic ray removal. Allowed methods are
@@ -71,7 +72,8 @@
 #' - 1 = along the time axis (line by line),
 #' - 2 = along the wavelength axis (column by column).
 #'
-#' **Note:** This argument currently only affects the methods `smooth` and `smooth.spline`
+#' **Note:** This argument only affects methods `smooth`, `smooth.spline` and
+#' `smooth_RLum`.
 #'
 #' @param verbose [logical] (*with default*):
 #' enable/disable output to the terminal.
@@ -87,12 +89,12 @@
 #'
 #' @return Returns same object as input.
 #'
-#' @section Function version: 0.4.0
+#' @section Function version: 0.4.1
 #'
 #' @author Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
-#' @seealso [RLum.Data.Spectrum-class], [RLum.Analysis-class], [stats::smooth], [stats::smooth.spline],
-#' [smooth_RLum]
+#' @seealso [RLum.Data.Spectrum-class], [RLum.Analysis-class], [stats::smooth],
+#' [stats::smooth.spline], [smooth_RLum]
 #'
 #' @references
 #' Pych, W., 2004. A Fast Algorithm for Cosmic-Ray Removal from
@@ -109,7 +111,6 @@
 #' ## your.spectrum <- apply_CosmicRayRemoval(your.spectrum, method = "Pych")
 #' ## your.spectrum <- apply_CosmicRayRemoval(your.spectrum, method = "smooth")
 #'
-#' @md
 #' @export
 apply_CosmicRayRemoval <- function(
   object,
@@ -137,9 +138,6 @@ apply_CosmicRayRemoval <- function(
   ##handle the list and recall
   if(inherits(object, "list")){
     results_list <- lapply(object, function(o){
-      ##preset objects
-      record_id.spectra <- NULL
-
       ##RLum.Analysis
       if(inherits(o, "RLum.Analysis")){
          ##get id of RLum.Data.Spectrum objects in this object
@@ -150,6 +148,7 @@ apply_CosmicRayRemoval <- function(
          temp_o <- o@records[record_id.spectra]
 
       }else{
+        record_id.spectra <- NULL
         temp_o <- o
       }
 
@@ -170,7 +169,6 @@ apply_CosmicRayRemoval <- function(
       if(!is.null(record_id.spectra)){
         o@records[record_id.spectra] <- results
         return(o)
-
       }else{
         return(results)
       }
@@ -179,7 +177,6 @@ apply_CosmicRayRemoval <- function(
     ##final return, make sure that we return what we had as input
     if(!is.null(class_original)){
       return(results_list[[1]])
-
     }else{
       return(results_list)
     }
@@ -191,6 +188,11 @@ apply_CosmicRayRemoval <- function(
     .throw_error("'object' contains no data")
 
   .validate_args(method, c("smooth", "smooth.spline", "smooth_RLum", "Pych"))
+  .validate_positive_scalar(method.Pych.smoothing, int = TRUE)
+  .validate_positive_scalar(method.Pych.threshold_factor)
+  .validate_args(MARGIN, c(1, 2))
+  .validate_logical_scalar(verbose)
+  .validate_logical_scalar(plot)
 
   ##deal with additional arguments
   extraArgs <- modifyList(
@@ -198,7 +200,7 @@ apply_CosmicRayRemoval <- function(
       kind = "3RS3R",
       twiceit = TRUE,
       spar = NULL,
-      method = "median",
+      method_smooth_RLum = "median",
       k = NULL,
       fill = NA,
       align = "right"),
@@ -239,7 +241,7 @@ apply_CosmicRayRemoval <- function(
         X = object@data,
         MARGIN = MARGIN,
         FUN = .smoothing,
-        method = extraArgs$method[1],
+        method = extraArgs$method_smooth_RLum[1],
         k = max(c(1, min(c(
           if(MARGIN == 2)
            floor(ncol(object@data)/(ncol(object@data)/2))
@@ -267,7 +269,6 @@ apply_CosmicRayRemoval <- function(
       }
     }
 
-
   ## +++++++++++++++++++++++++++++++++++ (Pych) ++++++++++++++++++++++++++++++##
   }else if(method == "Pych"){
     ## grep data matrix
@@ -281,10 +282,8 @@ apply_CosmicRayRemoval <- function(
 
       ##(2) - correct estimation of sd by 1-sigma clipping
       temp.sd.corr <- sd(object.data.temp[
-
         object.data.temp[,x] >= (mean(object.data.temp[,x]) - temp.sd) &
           object.data.temp[,x] <= (mean(object.data.temp[,x]) + temp.sd)
-
         , x])
 
       ##(3) - construct histogram of count distribution
@@ -312,7 +311,6 @@ apply_CosmicRayRemoval <- function(
       temp.hist.nonzerobin.diff <- diff(
         temp.hist$breaks[temp.hist.nonzerobin])
 
-
       ## select the first value where the threshold is reached
       ## factor 3 is defined by Pych (2003)
       temp.hist.thres <- which(
@@ -339,7 +337,6 @@ apply_CosmicRayRemoval <- function(
 
       ##(8) - return histogram used for the removal as plot
       if(plot){
-
         plot(temp.hist,
              xlab = "Signal intensity [a.u.]",
              main = "Cosmic-ray removal histogram")
@@ -352,7 +349,6 @@ apply_CosmicRayRemoval <- function(
           mtext(side = 3, paste0("Frame: ", x, " (",
                                  colnames(object.data.temp)[x],
                                  ")"))
-
         }else{
           mtext(side = 3, paste0("Frame: ", x, " (",
                                  colnames(object.data.temp)[x],
@@ -368,21 +364,20 @@ apply_CosmicRayRemoval <- function(
           sum(temp.hist$counts[temp.hist.thres:length(temp.hist$counts)]),
           silent = TRUE)
 
-        if(is(sum.corrected.channels)[1] == "try-error"){sum.corrected.channels <- 0}
+        if (inherits(sum.corrected.channels, "try-error"))
+          sum.corrected.channels <- 0
 
-        cat("[apply_CosmicRayRemoval()] >> ")
-        cat(paste(sum.corrected.channels, " channels corrected in frame ", x, "\n", sep = ""))
+        .throw_message(">> ", sum.corrected.channels,
+                       " channels corrected in frame ", x, "\n", error = FALSE)
       }
 
       ##return object
       return(object.data.temp[,x])
-
     })#end loop
   }
 
-
   ## Rotate matrix if required
-  if(MARGIN[1] == 1)
+  if (MARGIN[1] == 1 && method != "Pych")
     object.data.temp.smooth <- t(object.data.temp.smooth)
 
   # Correct row and column names --------------------------------------------
@@ -390,12 +385,10 @@ apply_CosmicRayRemoval <- function(
   rownames(object.data.temp.smooth) <- rownames(object@data)
 
   # Return Output------------------------------------------------------------
-  temp.output <- set_RLum(
+  set_RLum(
     class = "RLum.Data.Spectrum",
     recordType = object@recordType,
     curveType = object@curveType,
     data = object.data.temp.smooth,
     info = object@info)
-
-  invisible(temp.output)
 }
