@@ -9,7 +9,7 @@
 #' resolution and values are interpolated for the required spectral resolution using
 #' the function [stats::approx][stats::approxfun]
 #'
-#' If the energy calibration differes for both data set `NA` values are produces that
+#' If the energy calibration differs for both data set `NA` values are produces that
 #' will be removed from the matrix.
 #'
 #' @param object [RLum.Data.Spectrum-class] or [RLum.Analysis-class] (**required**):
@@ -45,62 +45,51 @@
 #' ##
 #' ## your.spectrum <- apply_EfficiencyCorrection(your.spectrum, )
 #'
-#' @md
 #' @export
 apply_EfficiencyCorrection <- function(
   object,
   spectral.efficiency
-){
-
+) {
+  .set_function_name("apply_EfficiencyCorrection")
+  on.exit(.unset_function_name(), add = TRUE)
 
   # self-call -----------------------------------------------------------------------------------
 
   ##case we have a list
-  if(class(object) == "list"){
+  if(inherits(object, "list")){
     output_list <- lapply(object, function(o){
-      if(class(o) == "RLum.Data.Spectrum" || class(o) == "RLum.Analysis"){
+      if(inherits(o, "RLum.Data.Spectrum") || inherits(o, "RLum.Analysis")){
         apply_EfficiencyCorrection(object = o, spectral.efficiency = spectral.efficiency)
 
       }else{
-        warning(paste0("[apply_EfficiencyCorrection()] Skipping ",class(o)," object in input list."), call. = FALSE)
+        .throw_warning("Skipping '", class(o), "' object in input list")
         return(o)
       }
-
     })
 
     return(output_list)
-
   }
 
   ##the case of an RLum.Analysis object
-  if(class(object) == "RLum.Analysis"){
+  if(inherits(object, "RLum.Analysis")){
     object@records <- lapply(object@records, function(o){
-      if(class(o) == "RLum.Data.Spectrum"){
+      if(inherits(o, "RLum.Data.Spectrum")){
         apply_EfficiencyCorrection(object = o, spectral.efficiency = spectral.efficiency)
 
       }else{
-        warning(paste0("[apply_EfficiencyCorrection()] Skipping ",class(o)," object in input list."), call. = FALSE)
+        .throw_warning("Skipping '", class(o), "' object in input list")
         return(o)
       }
-
     })
 
     return(object)
-
   }
 
 
+  ## Integrity checks -------------------------------------------------------
 
-  # Integrity check -----------------------------------------------------------
-
-  ##check if object is of class RLum.Data.Spectrum
-  if(class(object) != "RLum.Data.Spectrum")
-    stop("[apply_EfficiencyCorrection()] Input object is not of type RLum.Data.Spectrum",call. = FALSE)
-
-
-  if(class(spectral.efficiency) != "data.frame")
-    stop("[apply_EfficiencyCorrection()] 'spectral.efficiency' is not of type data.frame", call. = FALSE)
-
+  .validate_class(object, "RLum.Data.Spectrum")
+  .validate_class(spectral.efficiency, "data.frame")
 
   ## grep data matrix from the input object
   temp.matrix <- as(object, "matrix")
@@ -110,7 +99,7 @@ apply_EfficiencyCorrection <- function(
 
   ##test max
   if(max(temp.efficiency[,2]) > 1)
-    stop("[apply_EfficiencyCorrection()] Relative quantum efficiency values > 1 are not allowed.", call. = FALSE)
+    .throw_error("Relative quantum efficiency values > 1 are not allowed")
 
   # Apply method ------------------------------------------------------------
 
