@@ -147,7 +147,6 @@
 #' calc_AliquotSize(grain.size = c(100,200), sample.diameter = 8,
 #'                  grains.counted = c(2525,2312,2880), MC.iter = 100)
 #'
-#' @md
 #' @export
 calc_AliquotSize <- function(
   grain.size,
@@ -453,7 +452,7 @@ calc_AliquotSize <- function(
     if (settings$legend) {
       legend("topright", legend = c("mean","median", "0.05 / 0.95 quantile"),
              lty = c(2, 4, 3), bg = "white", box.col = "white",
-             cex = 0.9 * settings$cex)
+             cex = 0.9)
     }
 
     ## BOXPLOT
