@@ -97,7 +97,6 @@
 #' ##apply the central dose model
 #' calc_CentralDose(ExampleData.DeValues$CA1)
 #'
-#' @md
 #' @export
 calc_CentralDose <- function(
   data,
@@ -118,8 +117,8 @@ calc_CentralDose <- function(
 
   ##remove NA values
   if (anyNA(data)) {
-    message("[calc_CentralDose()] ", length(which(is.na(data))),
-            " NA values removed from dataset")
+    .throw_message(length(which(is.na(data))), " NA values removed from dataset",
+                   error = FALSE)
     data <- na.exclude(data)
   }
 
