@@ -181,7 +181,6 @@
 #' ## fitted components
 #' get_RLum(object = FMM, data.object = "components")
 #'
-#' @md
 #' @export
 calc_FiniteMixture <- function(
   data,
@@ -242,8 +241,7 @@ calc_FiniteMixture <- function(
   ## console output
   verbose <- TRUE
   if("verbose" %in% names(extraArgs)) {
-    verbose<- extraArgs$verbose
-    .validate_logical_scalar(verbose)
+    verbose <- .validate_logical_scalar(extraArgs$verbose, name = "'verbose'")
   }
 
   ##============================================================================##
@@ -646,10 +644,7 @@ calc_FiniteMixture <- function(
   min.dose <- min(object@data$data[, 1]) - sd(object@data$data[, 1]) / 2
 
   ## determine y-axis scaling
-  y.scale <- c(min.dose, max.dose)
-  if ("dose.scale" %in% names(extraArgs)) {
-    y.scale <- extraArgs$dose.scale
-  }
+  y.scale <- extraArgs$dose.scale %||% c(min.dose, max.dose)
 
   ## create empty plot without x-axis
   for (i in 1:n.plots) {
@@ -696,11 +691,7 @@ calc_FiniteMixture <- function(
     }
 
     ## x-axis (density)
-    if ("pdf.scale" %in% names(extraArgs)) {
-      x.scale <- extraArgs$pdf.scale
-    } else {
-      x.scale <- max(dens) * 1.1
-    }
+    x.scale <- extraArgs$pdf.scale %||% max(dens) * 1.1
 
     ## LOOP - iterate over number of components
     dens.sum <- 0
