@@ -21,7 +21,7 @@
 #' constant and **would not** applicable when the background varies as,
 #' e.g., as observed for the early light subtraction method.
 #'
-#' **sig0**
+#' **`sig0`**
 #'
 #' This argument allows to add an extra component of error to the final `Lx/Tx`
 #' error value. The input will be treated as factor that is multiplied with
@@ -30,7 +30,7 @@
 #' \deqn{se(LxTx) = \sqrt(se(LxTx)^2 + (LxTx * sig0)^2)}
 #'
 #'
-#' **background.count.distribution**
+#' **`background.count.distribution`**
 #'
 #' This argument allows selecting the distribution assumption that is used for
 #' the error calculation. According to Galbraith (2002, 2014) the background
@@ -60,16 +60,17 @@
 #' input is given the `Tx.data` will be treated as `NA` and no `Lx/Tx` ratio
 #' is calculated.
 #'
-#' @param signal.integral [numeric] (**required**): vector with the limits for the signal integral.
-#' Can be set to `NA` than now integrals are considered and all other integrals are set to `NA` as well.
+#' @param signal.integral [numeric] (**required**):
+#' vector with the limits for the signal integral. If set to `NA`, no integrals
+#' are considered and all other integrals are ignored.
 #'
 #' @param signal.integral.Tx [numeric] (*optional*):
 #' vector with the limits for the signal integral for the `Tx`-curve. If
 #' missing, the value from `signal.integral` is used.
 #'
 #' @param background.integral [numeric] (**required**):
-#' vector with the bounds for the background integral.
-#' Can be set to `NA` than now integrals are considered and all other integrals are set to `NA` as well.
+#' vector with the limits for the background integral. If set to `NA`, no
+#' integrals are considered and all other integrals ignored.
 #'
 #' @param background.integral.Tx [numeric] (*optional*):
 #' vector with the limits for the background integral for the `Tx` curve.
@@ -139,8 +140,7 @@
 #' @author
 #' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
-#' @seealso [RLum.Data.Curve-class], [Analyse_SAR.OSLdata], [fit_DoseResponseCurve],
-#' [analyse_SAR.CWOSL]
+#' @seealso [RLum.Data.Curve-class], [fit_DoseResponseCurve], [analyse_SAR.CWOSL]
 #'
 #' @references Duller, G., 2018. Analyst v4.57 - User Manual.
 #' `https://users.aber.ac.uk/ggd`\cr
@@ -168,7 +168,6 @@
 #' ##get results object
 #' get_RLum(results)
 #'
-#' @md
 #' @export
 calc_OSLLxTxRatio <- function(
   Lx.data,
@@ -188,6 +187,13 @@ calc_OSLLxTxRatio <- function(
 
   ## Integrity checks -------------------------------------------------------
   .validate_class(Lx.data, c("RLum.Data.Curve", "data.frame", "numeric", "matrix"))
+  .validate_not_empty(Lx.data)
+  .validate_class(Tx.data, c("RLum.Data.Curve", "data.frame", "numeric", "matrix"),
+                  null.ok = TRUE)
+  .validate_class(sigmab, "numeric", null.ok = TRUE)
+  if (!is.null(sigmab) && length(sigmab) > 2) {
+    .throw_error("'sigmab' can have at most length 2")
+  }
 
   ## Lx - coerce if required
   Lx.data <- switch(
@@ -201,8 +207,6 @@ calc_OSLLxTxRatio <- function(
 
   ## Tx - coerce if required
   if(!is.null(Tx.data)){
-    .validate_class(Tx.data, c("RLum.Data.Curve", "data.frame", "numeric", "matrix"))
-
     Tx.data <- switch(
       class(Tx.data)[1],
       "RLum.Data.Curve" = as(Tx.data, "data.frame"),
@@ -293,15 +297,6 @@ calc_OSLLxTxRatio <- function(
     background.integral.Tx <- background.integral
   }
 
-  ##check sigmab
-  if (!is.null(sigmab)) {
-    .validate_class(sigmab, "numeric")
-
-    if (length(sigmab) > 2) {
-      .throw_error("'sigmab' can have at most length 2")
-    }
-  }
-
   ##--------------------------------------------------------------------------##
   ##(2) - read data and produce background subtracted values
 
@@ -313,13 +308,7 @@ calc_OSLLxTxRatio <- function(
   n.Tx <- length(signal.integral.Tx)
 
   ##use previous BG and account for the option to set different integral limits
-  if(use_previousBG){
-    m.Tx <- m
-
-  }else{
-    m.Tx <- length(background.integral.Tx)
-  }
-
+  m.Tx <- if (use_previousBG) m else length(background.integral.Tx)
   k.Tx <- m.Tx/n.Tx
 
   ##LnLx (comments are corresponding variables to Galbraith, 2002)
