@@ -121,7 +121,6 @@
 #'  ylab = "Luminescence [a.u.]"
 #' )
 #'
-#'@md
 #'@export
 convert_Wavelength2Energy <- function(
   object,
@@ -170,7 +169,8 @@ convert_Wavelength2Energy <- function(
     ##this only works on RLum.Data.Spectrum objects and is sugar for using RLum-objects
     if(any("curveDescripter" %in% names(object@info))){
      if(any(grepl(pattern = "energy", x = tolower(object@info$curveDescripter), fixed = TRUE))){
-         message("[convert_Wavelength2Energy()] Your object has already an energy scale, nothing done!")
+        .throw_message("'object' has already an energy scale, nothing done",
+                       error = FALSE)
          return(object)
      }
     }
@@ -201,7 +201,10 @@ convert_Wavelength2Energy <- function(
       .throw_error("'object' should have at least two columns")
     }
 
-    temp <- as.matrix(object[,2:ncol(object)])
+    temp <- as.matrix(object[, 2:ncol(object), drop = FALSE])
+    if (!is.numeric(temp)) {
+      .throw_error("'object' should have only numeric fields")
+    }
 
     ##set rownames
     rownames(temp) <- object[,1]
