@@ -19,16 +19,17 @@
 #'of the ROI (first two columns) and the diameter of the circular ROI. All numbers must by of type [integer]
 #'and will forcefully coerced into such numbers using `as.integer()` regardless.
 #'
-#'@param roi_summary (**with default**): if `"mean"` (the default) defines what is returned
-#'in the element `roi_summary`; alternatively `"mean"`, `"median"`, `"sd"` or `"sum"` can be chosen.
+#'@param roi_summary (*with default*): defines what is returned in the
+#'`roi_summary` element; it can be `"mean"` (default), `"median"`, `"sd"` or
+#'`"sum"`.
 #'Pixel values are conveniently summarised using the above defined keyword.
 #'
-#'@param plot [logical] (*optional*): enables/disables control plot. Only the first
-#'image frame is shown
+#' @param plot [logical] (*optional*): enable/disable the plot output. Only
+#' the first image frame is shown.
 #'
 #'@return [RLum.Results-class] object with the following elements:
 #'`..$roi_signals`: a named [list] with all ROI values and their coordinates
-#'`..$roi_summary`: an [matrix] where rows are frames from the image, and columns are different ROI
+#'`..$roi_summary`: a [matrix] where rows are frames from the image, and columns are different ROI
 #'The element has two attributes: `summary` (the method used to summarise pixels) and `area` (the pixel area)
 #'`..$roi_coord`: a [matrix] that can be passed to [plot_ROI]
 #'
@@ -49,27 +50,29 @@
 #' roi <- matrix(c(2.,4,2,5,6,7,3,1,1), ncol = 3)
 #' extract_ROI(object = m, roi = roi, plot = TRUE)
 #'
-#'@md
 #'@export
 extract_ROI <- function(
   object,
   roi,
   roi_summary = "mean",
   plot = FALSE
-){
+) {
+  .set_function_name("extract_ROI")
+  on.exit(.unset_function_name(), add = TRUE)
 
 # Self call ---------------------------------------------------------------
-  if (is(object, "list"))
+  if (inherits(object, "list"))
     return(merge_RLum(lapply(object, extract_ROI, roi = roi, plot = plot)))
 
-# Check input -------------------------------------------------------------
-  ## check input for ROIs
-  if (!is.matrix(roi) || nrow(roi) < 1 || ncol(roi) < 3)
-    stop("[extract_ROI()] Please check the format of roi, it looks wrong!", call. = FALSE)
+  ## Integrity tests --------------------------------------------------------
 
-  ## check input for object
-  if (!is(object, "matrix") && !is(object, "array") &&  !is(object, "RLum.Data.Image"))
-    stop("[extract_ROI()] Input for argument 'object' not supported!", call. = FALSE)
+  .validate_class(object, c("RLum.Data.Image", "matrix", "array"),
+                  extra = "a 'list' of such objects")
+
+  ## check input for ROIs
+  .validate_class(roi, "matrix")
+  if (nrow(roi) < 1 || ncol(roi) < 3)
+    .throw_error("'roi' does not have the expected format")
 
   ## calculate the radius
   roi <- roi[,1:3]
@@ -82,10 +85,10 @@ extract_ROI <- function(
   a <- object
 
   ## try to convert into something meaningful
-  if (is(object, "RLum.Data.Image"))
+  if (inherits(object, "RLum.Data.Image"))
     a <- object@data
 
-  if (is(object, "matrix"))
+  if (is.matrix(object))
     a <- array(data = object, dim = c(nrow(object), ncol(object), 1))
 
 # Helper function ---------------------------------------------------------
@@ -115,7 +118,6 @@ extract_ROI <- function(
     ## iterate through a stack if needed
     temp <- lapply(1:(dim(a)[3]), function(z){
       .extract_pixel(a[,,z], roi[x,3], mid = roi[x,1:2])
-
     })
 
     ## compile into matrix
@@ -125,7 +127,6 @@ extract_ROI <- function(
     colnames(m) <- paste0("frame_", 1:ncol(m))
     attr(m, "px_coord") <- attr(temp[[1]], "coord")
     return(m)
-
   })
 
   ## add names
@@ -144,7 +145,7 @@ extract_ROI <- function(
       xlab = "x-dim [px]",
       useRaster = TRUE,
       main = "extract_ROIs() - control plot")
-    box()
+    graphics::box()
 
     ## visualise ROIs
     overlay <- a[,,1]
@@ -166,18 +167,13 @@ extract_ROI <- function(
     for (i in 1:nrow(roi)) {
       lines(shape::getellipse(rx = roi[i, 3], mid = c(roi[i, 1:2], dr = 0.1)), col = "red", lwd = 1.5)
       text(x = roi[i,1], y = roi[i,2], i, col = "black", cex = 1.2)
-
     }
-
   }
 
 # ROI summary -------------------------------------------------------------
   ## set roi fun and avoid add input
-  if(!any(roi_summary[1]%in%c("mean", "median", "sd", "sum")))
-    stop("[extract_ROI()] roi_summary method not supported, check manual!", call. = FALSE)
-
-  ## set function
-  roi_fun <- roi_summary[1]
+  .validate_class(roi_summary, "character")
+  roi_fun <- .validate_args(roi_summary, c("mean", "median", "sd", "sum"))
 
   ## create summary using matrixStats
   roi_summary <- matrix(unlist(
@@ -216,5 +212,4 @@ extract_ROI <- function(
         roi_coord = roi),
       info = list(
         call = sys.call())))
-
 }
