@@ -1,30 +1,27 @@
-#' Merge function for RLum.Analysis S4 class objects
-#'
-#' Function allows merging of RLum.Analysis objects and adding of allowed
-#' objects to an RLum.Analysis.
+#' @title Merge function for RLum.Analysis S4 class objects
 #'
+#' @description
 #' This function simply allows to merge [RLum.Analysis-class]
-#' objects. Moreover, other [RLum-class] objects can be added
+#' objects. Moreover, other [RLum.Data-class] objects can be added
 #' to an existing [RLum.Analysis-class] object. Supported objects
 #' to be added are: [RLum.Data.Curve-class],
 #' [RLum.Data.Spectrum-class] and
 #' [RLum.Data.Image-class].
 #'
-#' The order in the new [RLum.Analysis-class] object is the object
-#' order provided with the input list.
-#'
 #' @param objects [list] of [RLum.Analysis-class] (**required**):
 #' list of S4 objects of class `RLum.Analysis`. Furthermore other objects of
 #' class [RLum-class] can be added, see details.
 #'
-#' @return Return an [RLum.Analysis-class] object.
+#' @return
+#' Returns an [RLum.Analysis-class] object ordered according to the order
+#' provided with the input list.
 #'
 #' @note
 #' The information for the slot 'protocol' is taken from the first
 #' [RLum.Analysis-class] object in the input list. Therefore at
 #' least one object of type [RLum.Analysis-class] has to be provided.
 #'
-#' @section Function version: 0.2.0
+#' @section Function version: 0.2.1
 #'
 #' @author
 #' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
@@ -32,12 +29,10 @@
 #' @seealso [merge_RLum], [RLum.Analysis-class], [RLum.Data.Curve-class],
 #' [RLum.Data.Spectrum-class], [RLum.Data.Image-class], [RLum-class]
 #'
-#'
 #' @keywords utilities internal
 #'
 #' @examples
 #'
-#'
 #' ##merge different RLum objects from the example data
 #' data(ExampleData.RLum.Analysis, envir = environment())
 #' data(ExampleData.BINfileData, envir = environment())
@@ -47,7 +42,6 @@
 #'
 #' temp.merged <- merge_RLum.Analysis(list(curve, IRSAR.RF.Data, IRSAR.RF.Data))
 #'
-#' @md
 #' @export
 merge_RLum.Analysis<- function(
   objects
@@ -56,13 +50,12 @@ merge_RLum.Analysis<- function(
   on.exit(.unset_function_name(), add = TRUE)
 
   ## Integrity checks -------------------------------------------------------
-
   .validate_class(objects, "list")
   .validate_not_empty(objects)
 
   ##check if object is of class RLum
   temp.class.test <- sapply(objects, function(x) {
-    .validate_class(x, "RLum",
+    .validate_class(x, c("RLum.Analysis", "RLum.Data"),
                     name = "All elements of 'object'")
     class(x)[1]
   })
@@ -74,39 +67,28 @@ merge_RLum.Analysis<- function(
   }
 
 
-  # Merge objects -------------------------------------------------------------------------------
+  ## Merge objects ----------------------------------------------------------
 
   ##(0) get recent environment to later set variable temp.meta.data.first
   temp.environment  <- environment()
-  temp.meta.data.first <- NA; rm(temp.meta.data.first) #to avoid problems with the R check routine
+  temp.meta.data.first <- NULL
 
   ##(1) collect all elements in a list
-  temp.element.list <- unlist(lapply(1:length(objects), function(x){
+  temp.element.list <- unlist(lapply(objects, function(x) {
+    if (inherits(x, "RLum.Data"))
+      return(x)
 
-    .validate_class(objects[[x]], c("RLum.Analysis", "RLum.Data"))
-
-    ##Depending on the element the right functions is used
-    if (inherits(objects[[x]], "RLum.Analysis")) {
-
-      ##grep export meta data from the first RLum.Analysis objects an write
-      if(!exists("temp.meta.data.first")){
-
-        assign("temp.meta.data.first", objects[[x]]@protocol, envir = temp.environment)
-      }
-
-      ##return to list
-      get_RLum(objects[[x]])
-
-    } else {
-      ## RLum.Data.Curve, RLum.Data.Image, RLum.Data.Spectrum
-      ##return to list
-      objects[[x]]
+    ## x is an RLum.Analysis object
+    ## extract meta data from the first RLum.Analysis object
+    if (is.null(temp.meta.data.first)) {
+      assign("temp.meta.data.first", x@protocol, envir = temp.environment)
     }
+
+    get_RLum(x)
   }))
 
-
-  # Build new RLum.Analysis object --------------------------------------------------------------
-  temp.new.RLum.Analysis <- set_RLum(
+  ## return new RLum.Analysis object
+  set_RLum(
     class = "RLum.Analysis",
     originator = "merge_RLum.Analysis",
     records = temp.element.list,
@@ -117,9 +99,5 @@ merge_RLum.Analysis<- function(
     .pid = unlist(lapply(objects, function(x) {
       x@.uid
     }))
-    )
-
-
-  # Return object -------------------------------------------------------------------------------
-  return( temp.new.RLum.Analysis)
+  )
 }
