@@ -1,6 +1,8 @@
-#' @title  Merge Risoe.BINfileData objects or Risoe BIN-files
+#' @title Merge Risoe.BINfileData objects or Risoe BIN-files
 #'
-#' @description Function allows merging Risoe BIN/BINX files or [Risoe.BINfileData-class] objects.
+#' @description
+#' The function allows merging Risoe BIN/BINX files or [Risoe.BINfileData-class]
+#' objects.
 #'
 #' @details
 #' The function allows merging different measurements to one file or one
@@ -27,16 +29,14 @@
 #' `position.number.append.gap = 1` it will become:
 #' `1,3,5,7,9,11,13,15,17`.
 #'
-#' @param input.objects [character] with [Risoe.BINfileData-class] objects (**required**):
-#' Character vector with path and files names
-#' (e.g. `input.objects = c("path/file1.bin", "path/file2.bin")` or
+#' @param input.objects [character] or [Risoe.BINfileData-class] objects (**required**):
+#' Character vector with path and files names with ".bin" or ".binx" extension
+#' (e.g. `input.objects = c("path/file1.bin", "path/file2.bin")` or a list of
 #' [Risoe.BINfileData-class] objects (e.g. `input.objects = c(object1, object2)`).
-#' Alternatively a `list` is supported.
-#'
 #'
 #' @param output.file [character] (*optional*):
-#' File output path and name. If no value is given, a [Risoe.BINfileData-class] is
-#' returned instead of a file.
+#' File output path and name. If no value is given, a [Risoe.BINfileData-class]
+#' object returned instead of a file.
 #'
 #' @param keep.position.number [logical] (*with default*):
 #' Allows keeping the original position numbers of the input objects.
@@ -47,12 +47,17 @@
 #' `keep.position.number = FALSE` is used. See details for further
 #' information.
 #'
-#' @return Returns a `file` or a [Risoe.BINfileData-class] object.
+#' @param verbose [logical] (*with default*):
+#' enable/disable output to the terminal.
+#'
+#' @return
+#' Returns a [Risoe.BINfileData-class] object or writes to the BIN-file
+#' specified by `output.file`.
 #'
 #' @note
 #' The validity of the output objects is not further checked.
 #'
-#' @section Function version: 0.2.9
+#' @section Function version: 0.2.10
 #'
 #' @author
 #' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
@@ -62,10 +67,8 @@
 #' @references
 #' Duller, G.A.T., 2007. Analyst (Version 3.24) (manual). Aberystwyth University, Aberystwyth.
 #'
-#'
 #' @keywords IO manip
 #'
-#'
 #' @examples
 #'
 #' ##merge two objects
@@ -76,59 +79,50 @@
 #'
 #' object.new <- merge_Risoe.BINfileData(c(object1, object2))
 #'
-#' @md
 #' @export
 merge_Risoe.BINfileData <- function(
   input.objects,
   output.file,
   keep.position.number = FALSE,
-  position.number.append.gap = 0
-){
+  position.number.append.gap = 0,
+  verbose = TRUE
+) {
+  .set_function_name("merge_Risoe.BINfileData")
+  on.exit(.unset_function_name(), add = TRUE)
 
-  # Integrity Checks --------------------------------------------------------
+  ## Integrity checks -------------------------------------------------------
+
+  .validate_class(input.objects, c("character", "list"))
   if(length(input.objects) < 2){
-    message("[merge_Risoe.BINfileData()] Nothing done: at least two input objects are needed!")
+    .throw_message("At least two input objects are needed, nothing done",
+                   error = FALSE)
     return(input.objects)
-
   }
 
-  if(is(input.objects, "character") == TRUE){
+  if (is.character(input.objects)) {
     for(i in 1:length(input.objects)){
       if(file.exists(input.objects[i])==FALSE){
-        stop("[merge_Risoe.BINfileData()] File '", input.objects[i],
-             "' does not exist!", call. = FALSE)
+        .throw_error("File '", input.objects[i], "' does not exist")
       }
     }
 
   }else{
-
-    if(is(input.objects, "list") == TRUE){
-      for(i in 1:length(input.objects)){
-        if(is(input.objects[[i]], "Risoe.BINfileData") == FALSE){
-
-          stop("[merge_Risoe.BINfileData()] Input list does not contain Risoe.BINfileData objects!")
-
-        }
-
-      }
-
-    }else{
-      stop("[merge_Risoe.BINfileData()] Input object is neither a character nor a list!")
+    for (i in 1:length(input.objects)) {
+      .validate_class(input.objects[[i]], "Risoe.BINfileData",
+                      name = "All elements of 'input.objects'")
     }
   }
-
+  .validate_logical_scalar(verbose)
 
   # Import Files ------------------------------------------------------------
 
   ##loop over all files to store the results in a list
   ##or the input is already a list
 
-  if(is(input.objects, "character") == TRUE){
-    temp <- lapply(input.objects, read_BIN2R, txtProgressBar = FALSE)
-
+  if (is.character(input.objects)) {
+    temp <- lapply(input.objects, read_BIN2R, verbose = verbose)
   }else{
     temp <- input.objects
-
   }
 
   # Get POSITION values -------------------------------------------------------
@@ -147,62 +141,32 @@ merge_Risoe.BINfileData <- function(
     return(temp)
   }))
 
-
   temp.position.values <- c(temp[[1]]@METADATA[["POSITION"]], temp.position.values)
 
-
   # Get overall record length -----------------------------------------------
-  temp.record.length <- sum(sapply(1:length(temp), function(x){
-    length(temp[[x]]@METADATA[,"ID"])
-
-  }))
-
+  temp.record.length <- sum(sapply(temp, function(x) nrow(x@METADATA)))
 
   # Merge Files -------------------------------------------------------------
-  ##loop for similar input objects
-  for(i in 1:length(input.objects)){
-    if(exists("temp.new.METADATA") == FALSE){
-
-      temp.new.METADATA <- temp[[i]]@METADATA
-      temp.new.DATA <- temp[[i]]@DATA
-
-
-      if(inherits(try(temp[[i]]@.RESERVED, silent = TRUE), "try-error")){
-
-        temp.new.RESERVED <- list()
-
-      }else{
-
-        temp.new.RESERVED <- temp[[i]]@.RESERVED
-
-      }
-
-    }else{
-
-      temp.new.METADATA <- rbind(temp.new.METADATA, temp[[i]]@METADATA)
-      temp.new.DATA <- c(temp.new.DATA, temp[[i]]@DATA)
-
-      if(inherits(try(temp[[i]]@.RESERVED, silent = TRUE), "try-error")){
-
-        temp.new.RESERVED <- c(temp.new.RESERVED, list())
-
-      }else{
-
-        temp.new.RESERVED <- c(temp.new.RESERVED, temp[[i]]@.RESERVED)
-
-      }
+  temp.new.METADATA <- temp[[1]]@METADATA
+  temp.new.DATA <- temp[[1]]@DATA
+  temp.new.RESERVED <- if (".RESERVED" %in% slotNames(temp[[1]]))
+                         temp[[1]]@.RESERVED else list()
 
+  ## loop over the remaining input objects
+  for (i in 2:length(input.objects)) {
+    temp.new.METADATA <- rbind(temp.new.METADATA, temp[[i]]@METADATA)
+    temp.new.DATA <- c(temp.new.DATA, temp[[i]]@DATA)
+    if (".RESERVED" %in% slotNames(temp[[i]])) {
+      temp.new.RESERVED <- c(temp.new.RESERVED, temp[[i]]@.RESERVED)
     }
   }
 
-
   ##SET RECORD ID in METADATA
   temp.new.METADATA$ID <- 1:temp.record.length
 
   ##SET POSITION VALUES
-  if(keep.position.number == FALSE){
+  if (!keep.position.number) {
     temp.new.METADATA$POSITION <- temp.position.values
-
   }
 
   ##TODO version number?
@@ -211,17 +175,11 @@ merge_Risoe.BINfileData <- function(
     METADATA = temp.new.METADATA,
     DATA = temp.new.DATA,
     .RESERVED = temp.new.RESERVED
-
   )
 
-
   # OUTPUT ------------------------------------------------------------------
-  if(missing(output.file) == FALSE){
-    write_R2BIN(temp.new, output.file)
-
-  }else{
+  if (missing(output.file))
     return(temp.new)
 
-  }
-
+  write_R2BIN(temp.new, output.file, verbose = verbose)
 }
