@@ -86,7 +86,6 @@
 #' data(ExampleData.RLum.Analysis, envir = environment())
 #'
 #' @keywords internal
-#' @md
 #' @name methods_RLum
 NULL
 
@@ -136,8 +135,7 @@ plot.RLum.Data.Image <- function(x, y, ...) plot_RLum(object = x, ...)
 #' @export
 plot.Risoe.BINfileData <- function(x, y, ...) plot_Risoe.BINfileData(data = x, ...)
 
-#############################################################################
-# hist() ---------------
+# hist() -----------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -156,8 +154,7 @@ hist.RLum.Data.Curve <- function(x, ...) hist(as(get_RLum(x),"matrix")[,2])
 hist.RLum.Analysis <- function(x, ...) lapply(1:length_RLum(x), function(z){
   hist(as(get_RLum(x, record.id = z, ...),"matrix")[,2])})
 
-#############################################################################
-# methods for generic: summary()
+# summary() --------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @method summary RLum.Results
@@ -181,8 +178,7 @@ summary.RLum.Data.Image <- function(object, ...) summary(object@data)
 #' @export
 summary.RLum.Data.Curve <- function(object, ...) summary(object@data, ...)
 
-#############################################################################
-# methods for generic: subset()
+# subset() ---------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @method subset Risoe.BINfileData
@@ -190,7 +186,6 @@ summary.RLum.Data.Curve <- function(object, ...) summary(object@data, ...)
 #' @param records.rm [subset] [logical] (*with default*):
 #' remove records from data set, can be disabled, to just set the column `SET` to `TRUE` or `FALSE`
 #'
-#' @md
 #' @export
 subset.Risoe.BINfileData <- function(x, subset, records.rm = TRUE, ...) {
   .set_function_name("subset.Risoe.BINfileData")
@@ -233,8 +228,7 @@ subset.Risoe.BINfileData <- function(x, subset, records.rm = TRUE, ...) {
 subset.RLum.Analysis <- function(x, subset = NULL, ...) {
   do.call(get_RLum, list(object = x, drop = FALSE, subset = substitute(subset), env = parent.frame())) }
 
-#############################################################################
-# methods for generic: bin()
+# bin() ------------------------------------------------------------------------
 #' @rdname methods_RLum
 #' @export
 bin <- function(x, ...) {
@@ -251,8 +245,7 @@ bin.RLum.Data.Spectrum <- function(x, bin_size.row = 1, bin_size.col = 1, ...){
   bin_RLum.Data(x, bin_size.row = bin_size.row, bin_size.col = bin_size.col)
 }
 
-#############################################################################
-# methods for generic: length()
+# length() ---------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -270,8 +263,7 @@ length.RLum.Data.Curve <- function(x, ...) length_RLum(x)
 #' @export
 length.Risoe.BINfileData <- function(x, ...) length(x@METADATA$ID)
 
-#############################################################################
-# methods for generic: dim()
+# dim() ------------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -281,15 +273,14 @@ dim.RLum.Data.Curve <- function(x) dim(as(x, "matrix"))
 #' @export
 dim.RLum.Data.Spectrum <- function(x) dim(as(x, "matrix"))
 
-#############################################################################
-# methods for generic: rep()
+# rep() -------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
 rep.RLum <- function(x, ...) replicate_RLum(x, ...)
 
-#############################################################################
-# methods for generic: names()
+
+# names() -----------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -315,15 +306,15 @@ names.RLum.Results <- function(x, ...) names_RLum(x)
 #' @export
 names.Risoe.BINfileData <- function(x)  as.character(x@METADATA$LTYPE)
 
-#############################################################################
-# methods for generic: row.name()
+
+# row.name() --------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
 row.names.RLum.Data.Spectrum <- function(x, ...) rownames(as(x, "matrix"))
 
-#############################################################################
-# methods for generic: as.data.frame()
+
+# as.data.frame() ---------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -339,7 +330,7 @@ as.data.frame.RLum.Data.Spectrum <- function(x,  row.names = NULL, optional = FA
 as.data.frame.Risoe.BINfileData <- function(x,  row.names = NULL, optional = FALSE, ...) {
 
   ## set matrix
-  m <- matrix(NA, ncol = max(sapply(x@DATA, length)), nrow = length(x@DATA))
+  m <- matrix(NA, ncol = max(lengths(x@DATA)), nrow = length(x@DATA))
 
   ## rename columns
   colnames(m) <- paste0("C",1:ncol(m))
@@ -351,8 +342,8 @@ as.data.frame.Risoe.BINfileData <- function(x,  row.names = NULL, optional = FAL
   cbind(x@METADATA, as.data.frame(m))
 }
 
-#############################################################################
-# methods for generic: as.list()
+
+# as.list() ---------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -374,8 +365,9 @@ as.list.RLum.Data.Spectrum <- function(x, ...) as(x, "list")
 #' @export
 as.list.RLum.Analysis <- function(x, ...) as(x, "list")
 
-#############################################################################
-# methods for generic: as.matrix()
+
+# as.matrix() -------------------------------------------------------------
+
 #' @rdname methods_RLum
 #' @export
 as.matrix.RLum.Data.Curve <- function(x, ...) as(x, "matrix")
@@ -389,8 +381,8 @@ as.matrix.RLum.Data.Spectrum <- function(x, ...) as(x, "matrix")
 as.matrix.RLum.Data.Image <- function(x, ...) as(x, "matrix")
 # for RLum.Results ... makes no sense and may yield in unpredictable behaviour
 
-#############################################################################
-# methods for generic: is()
+
+# is() --------------------------------------------------------------------
 
 #For this function no S4 method was written, as this would come at the cost of performance and
 #is totally unnecessary
@@ -423,15 +415,14 @@ is.RLum.Analysis <- function(x, ...) is(x, "RLum.Analysis")
 #' @export
 is.RLum.Results <- function(x, ...) is(x, "RLum.Results")
 
-#############################################################################
-# methods for generic: merge()
+# merge() -----------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
 merge.RLum <- function(x, y, ...) merge_RLum(append(list(...), values = c(x, y)))
 
-#############################################################################
-# methods for generic: unlist()
+
+# unlist() ----------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @method unlist RLum.Analysis
@@ -449,8 +440,8 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
   }
 }
 
-#############################################################################
-# methods for generic: `+`
+
+# `+` ---------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #'
@@ -471,8 +462,8 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
 #' @export
 `+.RLum.Data.Spectrum` <- function(x, y) merge_RLum(list(x, y), merge.method = "sum")
 
-#############################################################################
-# methods for generic: `-`
+
+# `-` ---------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -482,8 +473,8 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
 #' @export
 `-.RLum.Data.Spectrum` <- function(x, y) merge_RLum(list(x, y), merge.method = "-")
 
-#############################################################################
-# methods for generic: `*`
+
+# `*` ---------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -493,8 +484,8 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
 #' @export
 `*.RLum.Data.Spectrum` <- function(x, y) merge_RLum(list(x, y), merge.method = "*")
 
-#############################################################################
-# methods for generic: `/`
+
+# `/` ---------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -504,8 +495,8 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
 #' @export
 `/.RLum.Data.Spectrum` <- function(x, y) merge_RLum(list(x, y), merge.method = "/")
 
-#############################################################################
-# methods for generic: `[`
+
+# `[` ---------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -522,9 +513,8 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
 #' @rdname methods_RLum
 #' @export
 `[.RLum.Analysis` <- function(x, i, drop = FALSE) {
-  if (is(i, "character")) {
+  if (is.character(i)) {
     get_RLum(x, recordType = i, drop = drop)
-
   } else{
     get_RLum(x, record.id = i, drop = drop)
   }
@@ -535,8 +525,7 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
 `[.RLum.Results` <- function(x, i, drop = TRUE) {get_RLum(x, data.object = i, drop = drop)}
 
 
-#############################################################################
-# methods for generic: `[<-`
+# `[<-` -------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
@@ -545,18 +534,16 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
   return(x)
 }
 
-#############################################################################
-# methods for generic: `[[`
+
+# `[[` --------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
 `[[.RLum.Analysis` <- function(x, i) {
-  if (is(i, "character")) {
+  if (is.character(i)) {
     get_RLum(x, recordType = i)
-
   } else{
     get_RLum(x, record.id = i)
-
   }
 }
 
@@ -564,8 +551,8 @@ unlist.RLum.Analysis <- function(x, recursive = TRUE, ...){
 #' @export
 `[[.RLum.Results` <- function(x, i) {get_RLum(x, data.object = i)}
 
-#############################################################################
-# methods for generic: `$`
+
+# `$` ---------------------------------------------------------------------
 
 #' @rdname methods_RLum
 #' @export
