@@ -63,7 +63,6 @@
 #' ##plot data
 #' plot_RLum.Data.Image(ExampleData.RLum.Data.Image)
 #'
-#' @md
 #' @export
 plot_RLum.Data.Image <- function(
   object,
@@ -71,15 +70,20 @@ plot_RLum.Data.Image <- function(
   par.local = TRUE,
   plot.type = "plot.raster",
   ...
-){
+) {
+  .set_function_name("plot_RLum.Data.Image")
+  on.exit(.unset_function_name(), add = TRUE)
 
-# Integrity check -----------------------------------------------------------
-  ##check if object is of class RLum.Data.Image
-  if(!inherits(object, "RLum.Data.Image"))
-    stop("[plot_RLum.Data.Image()] Input object is not of type RLum.Data.Image.", call. = FALSE)
+  ## Integrity checks -------------------------------------------------------
+
+  .validate_class(object, "RLum.Data.Image")
 
   ## extract object
   object <- object@data
+  if (length(dim(object)) != 3) {
+    ## the object is empty or malformed
+    return(NULL)
+  }
 
 # Define additional functions ---------------------------------------------
 .stretch <- function(x, type = "lin"){
@@ -96,7 +100,6 @@ plot_RLum.Data.Image <- function(
       x[x < 0] <- r[1]
       x[x > r[2]] <- r[2]
     }
-
   }
 
   if(type[1] == "hist")
@@ -105,6 +108,8 @@ plot_RLum.Data.Image <- function(
   return(x)
 }
 
+ plot.type <- .validate_args(plot.type, c("plot.raster", "contour"))
+
 # Plot settings -----------------------------------------------------------
 plot_settings <- modifyList(x = list(
     main = "RLum.Data.Image",
@@ -127,7 +132,6 @@ plot_settings <- modifyList(x = list(
     frames[1] <- max(1,min(frames))
     frames[length(frames)] <- min(dim(object)[3],max(frames))
     object <- object[,,frames,drop = FALSE]
-
   }
 
   ## enforce xlim, ylim and zlim directly here
@@ -156,7 +160,7 @@ plot_settings <- modifyList(x = list(
         x = image,
         useRaster = plot_settings$useRaster,
         axes = FALSE,
-        zlim = if(is.null(plot_settings$zlim_image)) range(image) else plot_settings$zlim_image,
+        zlim = plot_settings$zlim_image %||% range(image),
         xlab = plot_settings$xlab,
         ylab = plot_settings$ylab,
         main = paste0(plot_settings$main, " #",i),
@@ -174,7 +178,6 @@ plot_settings <- modifyList(x = list(
         ylab[c(1,length(ylab))] <- c(0,dim(x)[2])
         yat <- seq(0,1,length.out = length(ylab))
         graphics::axis(side = 2, at = yat, labels = ylab)
-
       }
 
       ## add legend
@@ -196,22 +199,16 @@ plot_settings <- modifyList(x = list(
         text(
           x = par()$usr[4] * 1.04,
           y = par()$usr[2],
-          labels = if(is.null(plot_settings$zlim_image)) {
-            format(max(x), digits = 1, scientific = TRUE)
-            } else {
-            format(plot_settings$zlim_image[2], digits = 1, scientific = TRUE)
-            },
+          labels = format(plot_settings$zlim_image[2] %||% max(x),
+                          digits = 1, scientific = TRUE),
           cex = 0.7,
           srt = 270,
           pos = 3)
         text(
           x = par()$usr[4] * 1.04,
           y = par()$usr[3],
-          labels = if(is.null(plot_settings$zlim_image)) {
-            format(min(x), digits = 1, scientific = TRUE)
-          } else {
-            format(plot_settings$zlim_image[1], digits = 1, scientific = TRUE)
-          },
+          labels = format(plot_settings$zlim_image[1] %||% min(x),
+                          digits = 1, scientific = TRUE),
           cex = 0.7,
           pos = 3,
           srt = 270)
@@ -224,13 +221,12 @@ plot_settings <- modifyList(x = list(
       graphics::contour(
         x = x[,,1],
         axes = FALSE,
-        zlim = if(is.null(plot_settings$zlim_image)) range(x) else plot_settings$zlim_image,
+        zlim = plot_settings$zlim_image %||% range(x),
         xlab = plot_settings$xlab,
         ylab = plot_settings$ylab,
         main = paste0(plot_settings$main, " #",i),
         col = plot_settings$col)
       graphics::box()
-
      }
 
     ## axes
@@ -244,12 +240,6 @@ plot_settings <- modifyList(x = list(
       ylab[c(1,length(ylab))] <- c(0,dim(x)[1])
       yat <- seq(0,1,length.out = length(ylab))
       graphics::axis(side = 2, at = yat, labels = ylab)
-
     }
-
-  }else{
-    stop("[plot_RLum.Data.Image()] Unknown plot type.", call. = FALSE)
-
   }
-
 }
