@@ -1,8 +1,8 @@
-#' General plot function for RLum S4 class objects
+#' @title General plot function for RLum S4 class objects
 #'
-#' Function calls object specific plot functions for RLum S4 class objects.
+#' @description Function calls object specific plot functions for RLum S4 class objects.
 #'
-#' The function provides a generalised access point for plotting specific
+#' @details The function provides a generalised access point for plotting specific
 #' [RLum-class] objects.\cr
 #' Depending on the input object, the
 #' corresponding plot function will be selected.  Allowed arguments can be
@@ -56,9 +56,8 @@
 #' #plot RLum object
 #' plot_RLum(temp)
 #'
-#' @md
 #' @export
-plot_RLum<- function(
+plot_RLum <- function(
   object,
   ...
 ) {
@@ -109,7 +108,7 @@ plot_RLum<- function(
 
       ##set also mtext, but in a different way
       if(!"mtext" %in% names(list(...))){
-        if(is(object[[1]], "RLum.Analysis")){
+        if (inherits(object[[1]], "RLum.Analysis")) {
           mtext <- paste("Record:", 1:length(object))
 
         }else{
@@ -119,10 +118,11 @@ plot_RLum<- function(
         mtext <- rep(list(...)$mtext, length.out = length(object))
       }
       for (i in 1:length(object)) {
-        RLum.dispatcher(object = object[[i]],
-                        main = main[[i]],
-                        mtext = mtext[[i]],
-                        ...)
+        RLum.dispatcher(
+          object = object[[i]],
+          main = main[[i]],
+          mtext = mtext[[i]],
+          ...)
       }
     }
   }else{
