@@ -27,7 +27,6 @@
 #'file <- system.file("extdata/HeliosOSL_Example.osl", package = "Luminescence")
 #'read_HeliosOSL2R(file)
 #'
-#'@md
 #'@export
 read_HeliosOSL2R <- function(
   file,
@@ -62,7 +61,7 @@ read_HeliosOSL2R <- function(
   ## Integrity checks -------------------------------------------------------
 
   .validate_class(file, c("character", "list"))
-  .validate_not_empty(file)
+  .validate_length(file, 1)
 
   ## check file format
   if (tolower(ext <- tools::file_ext(file)) != "osl")
@@ -84,7 +83,7 @@ read_HeliosOSL2R <- function(
   lines <- readLines(file)
 
     ## get footer lines id, which is printed in quotes but not the first
-    footer_id <- which(grepl(pattern = '\\"', x = lines, fixed = FALSE))[2]
+    footer_id <- grep(pattern = '\\"', x = lines)[2]
 
     ## import data measurement data
     df <- read.table(
