@@ -3,13 +3,17 @@
 #' @description Import files produced by the IR-RF 'ImageJ' macro (`SR-RF.ijm`; Mittelstraß and Kreutzer, 2021) into R and create a list of [RLum.Analysis-class]
 #' objects
 #'
-#' @details The results of spatially resolved IR-RF data are summarised in so-called RF-files ((Mittelstraß and Kreutzer, 2021).
+#' @details The results of spatially resolved IR-RF data are summarised in
+#' so-called RF-files (Mittelstraß and Kreutzer, 2021).
 #' This functions provides an easy import to process the data seamlessly with the R package 'Luminescence'.
-#' The output of the function can be passed to the function [analyse_IRSAR.RF]
+#' The output of the function can be passed to function [analyse_IRSAR.RF].
 #'
 #' @param file [character] (**required**): path and file name of the RF file. Alternatively a list of file
 #' names can be provided.
 #'
+#' @param verbose [logical] (*with default*):
+#' enable/disable output to the terminal.
+#'
 #' @param ... not used, only for compatible reasons
 #'
 #' @return Returns an S4 [RLum.Analysis-class] object containing
@@ -32,49 +36,53 @@
 #' file <- system.file("extdata", "RF_file.rf", package = "Luminescence")
 #' temp <- read_RF2R(file)
 #'
-#' @md
 #' @export
 read_RF2R <- function(
   file,
+  verbose = TRUE,
   ...
 ) {
+  .set_function_name("read_RF2R")
+  on.exit(.unset_function_name(), add = TRUE)
 
 # Self-call -----------------------------------------------------------------------------------
   if(inherits(file, "list")){
     results_list <- lapply(file, function(f){
-      temp <- try(read_RF2R(file = f), silent = TRUE)
+      if (!.validate_class(f, "character", throw.error = FALSE,
+                           name = "All elements of 'file'")) {
+        return(NULL)
+      }
+      temp <- try(read_RF2R(file = f, verbose = verbose), silent = TRUE)
 
       ##check whether it worked
       if(inherits(temp, "try-error")){
-        message("[read_RF2R()] Error: Import for file '", f,
-                "' failed, NULL returned")
+        .throw_message("Import for file '", f, "' failed, NULL returned")
         return(NULL)
       }else{
         return(temp)
       }
-
     })
 
     return(unlist(results_list, recursive = FALSE))
-
   }
 
 
-# Integrity check -----------------------------------------------------------------------------
+  ## Integrity checks -------------------------------------------------------
+
+  .validate_class(file, "character", extra = "'list'")
+  .validate_not_empty(file)
+
   ##throw warning if we have a vector
   if(length(file) > 1){
-    warning("[read_RF2R()] 'file' has a length > 1. Only the first element was taken!
-            If you want to import multiple files, 'file' has to be of type 'list'.", call. = TRUE)
+    .throw_warning("'file' has length > 1, only the first element was taken. ",
+                   "If you want to import multiple files, 'file' has to be ",
+                   "of type 'list'")
     file <- file[1]
   }
 
-  ##check input
-  if(!inherits(file, "character"))
-    stop("[read_RF2R()] 'file' needs to be of type character!", call. = FALSE)
-
   ##check whether file is available
   if(!file.exists(file))
-    stop("[read_RF2R()] File '", file, "' does not exist!", call. = FALSE)
+    .throw_error("File '", file, "' does not exist")
 
   ##read first line to ensure the format
   vers_str <-  readLines(file, 1)
@@ -83,9 +91,16 @@ read_RF2R <- function(
                               regexpr("(?<=macro\\_version=)[0-9-.]+", vers_str, perl = TRUE))
 
   if (!any(version_found %in% version_supported))
-    stop("[read_RF2R()] File format not supported!", call. = FALSE)
+    .throw_error("File format not supported")
 
-# Import --------------------------------------------------------------------------------------
+  ## Import -----------------------------------------------------------------
+
+  if (verbose) {
+    cat("\n[read_RF2R()] Importing ...")
+    cat("\n path: ", dirname(file))
+    cat("\n file: ", .shorten_filename(basename(file)))
+    cat("\n")
+  }
 
   ##import the entire file
   temp <- readLines(file, warn = FALSE)
@@ -109,8 +124,7 @@ read_RF2R <- function(
 
     ##test the header
     if(inherits(header, 'try-error')){
-      message("[read_RF2R()] Error: Header extraction failed, ",
-              "trying to continue without ... ")
+      .throw_message("Header extraction failed, trying to continue without ...")
       header <- NA
     }
 
@@ -204,7 +218,6 @@ read_RF2R <- function(
 
         }else{
           temp_curve <- m_RF_reg[,c(2,2 + a)]
-
         }
 
         ##write curve
@@ -215,8 +228,6 @@ read_RF2R <- function(
           recordType = "RF",
           data = temp_curve
         )
-
-
       })
 
       ##create RLum.Analysis object
@@ -227,10 +238,8 @@ read_RF2R <- function(
                  as.list(df_statistics[a,]),
                  header
                  ))
-
     })
 
 # Return --------------------------------------------------------------------------------------
 return(object_list)
-
 }
