@@ -113,7 +113,6 @@
 #' .as.latex.table(output)
 #' }
 #'
-#' @md
 #' @export
 use_DRAC <- function(
   file,
@@ -190,14 +189,14 @@ use_DRAC <- function(
   if (nrow(input.raw) > 5000)
     .throw_error("The limit of allowed datasets is 5000!")
 
+  .validate_logical_scalar(print_references)
   citation_style <- .validate_args(citation_style,
                                    c("text", "Bibtex", "citation", "html",
                                      "latex", "R"))
 
-  # Set helper function -------------------------------------------------------------------------
-  ## The real data are transferred without any encryption, so we have to mask the original
 
-  ##(0) set masking function
+  ## Helper function --------------------------------------------------------
+  ## The data are transferred without encryption, so we mask the original
   .masking <- function(mean, sd, n) {
     temp <- rnorm(n = 30 * n, mean = mean, sd = sd)
     t(vapply(seq(1, length(temp), 30), function(x) {
@@ -271,16 +270,17 @@ use_DRAC <- function(
     silent = TRUE)
 
   ## check for correct response
-  if (inherits(DRAC.response, "try-error") || DRAC.response$status_code != 200) {
-    if(inherits(DRAC.response, "try-error"))
-       DRAC.response$status_code <- "URL invalid"
-
+  if (inherits(DRAC.response, "try-error")) {
+    .throw_error("Transmission failed with error: ",
+                 attr(DRAC.response, "condition")$message)
+  } else if (DRAC.response$status_code != 200) {
     .throw_error("Transmission failed with HTTP status code: ",
                  DRAC.response$status_code)
-  } else {
-    if (settings$verbose) message("\t The request was successful, processing the reply...")
   }
 
+  if (settings$verbose)
+    message("\t The request was successful, processing the reply...")
+
   ## assign DRAC response data to variables
   http.header <- DRAC.response$header
   DRAC.content <- httr::content(x = DRAC.response, as = "text")
@@ -288,25 +288,28 @@ use_DRAC <- function(
   ## if the input was valid from a technical standpoint, but not with regard
   ## contents, we indeed get a valid response, but no DRAC output
   if (!grepl("DRAC Outputs", DRAC.content)) {
-    error_start <- max(gregexpr("drac_field_error", DRAC.content)[[1]])
-    error_end <- regexec('textarea name=', DRAC.content)[[1]]
-    error_msg <- substr(DRAC.content, error_start, error_end)
-
-    # nocov start
     on.exit({
-      reply <- readline("Do you want to see the DRAC error message (Y/N)?")
-      if (reply == "Y" || reply == "y" || reply == 1)
-        cat(error_msg)
-    }, add = TRUE)
-    # nocov end
+      reply <- readline("Do you want to see the DRAC error message (y/N)? ")
+      if (reply %in% c("Y", "y", "1")) {
+        ## convert to html and extract the error fields
+        html <- XML::htmlParse(DRAC.content, asText = TRUE)
+        error <- XML::xpathSApply(html, "//div[@class='drac_field_error']",
+                                  XML::xmlValue)
 
-    .throw_error("\n\t We got a response from the server, but it\n",
-                 "\t did not contain DRAC output. Please check\n",
-                 "\t your data and verify its validity.\n")
-  } else {
-    if (settings$verbose) message("\t Finalising the results...")
+        ## extract the fragment we are given if no drac_field_error is found
+        if (length(error) == 0)
+          error <- XML::xpathSApply(html, "//body", XML::xmlValue) # nocov
+
+        cat("\n", paste(error, collapse = "\n"), "\n", sep = "")
+      }
+    }, add = TRUE)
+
+    .throw_error("The response from the server did not contain DRAC output, ",
+                 "please check your data and verify its validity.")
   }
 
+  if (settings$verbose) message("\t Finalising the results...")
+
   ## split header and content
   DRAC.content.split <- strsplit(x = DRAC.content,
                                  split = "DRAC Outputs\n\n")
@@ -402,7 +405,6 @@ use_DRAC <- function(
     }
   }
 
-
   ## return output
   DRAC.return <- set_RLum(
     "RLum.Results",
