@@ -9,7 +9,9 @@ test_that("input validation", {
   expect_error(analyse_IRSAR.RF("test"),
                "'object' should be of class 'RLum.Analysis'")
   expect_error(analyse_IRSAR.RF(iris),
-               "'object' should be of class 'RLum.Analysis'")
+               "'object' should be of class 'RLum.Analysis' or a 'list'")
+   expect_error(analyse_IRSAR.RF(list(iris)),
+               "All elements of 'object' should be of class 'RLum.Analysis'")
   expect_error(analyse_IRSAR.RF(set_RLum("RLum.Analysis")),
                "'object' cannot be an empty RLum.Analysis")
   expect_error(analyse_IRSAR.RF(IRSAR.RF.Data, n.MC = 0),
@@ -41,13 +43,13 @@ test_that("input validation", {
 
   ## RF_nat.lim
   expect_error(analyse_IRSAR.RF(IRSAR.RF.Data, RF_nat.lim = "error"),
-               "'RF_nat.lim' should be of class 'numeric' or 'integer'")
+               "'RF_nat.lim' should be of class 'numeric', 'integer' or NULL")
   expect_warning(analyse_IRSAR.RF(IRSAR.RF.Data, RF_nat.lim = 6),
                  "'RF_nat.lim' out of bounds, reset to")
 
   ## RF_reg.lim
   expect_error(analyse_IRSAR.RF(IRSAR.RF.Data, RF_reg.lim = "error"),
-               "'RF_reg.lim' should be of class 'numeric' or 'integer'")
+               "'RF_reg.lim' should be of class 'numeric', 'integer' or NULL")
   expect_warning(analyse_IRSAR.RF(IRSAR.RF.Data, RF_reg.lim = 2000),
                  "'RF_reg.lim' out of bounds, reset to")
   expect_error(analyse_IRSAR.RF(IRSAR.RF.Data, RF_reg.lim = 521),
