@@ -57,6 +57,8 @@ suppressWarnings( # warnings thrown by analyse_SAR.CWOSL and fit_DoseResponseCur
 
 test_that("check plot stuff", {
   ## it should throw a warning about the plot size
+  pdf.out <- tempfile(fileext = ".pdf")
+  pdf(pdf.out, width = 6, height = 8)
   expect_warning(analyse_pIRIRSequence(
     object,
     signal.integral.min = 1,
@@ -71,10 +73,10 @@ test_that("check plot stuff", {
     verbose = FALSE),
     "[analyse_pIRIRSequence()] Argument 'plot' reset to 'FALSE'",
     fixed = TRUE)
+  dev.off()
 
   ## this should not throw any warning because we print to a large enough pdf
-  pdf.out <- tempfile(fileext = ".pdf")
-  pdf(pdf.out, width = 20, height = 20)
+  pdf(pdf.out, width = 16, height = 16)
   expect_silent(analyse_pIRIRSequence(
     object,
     signal.integral.min = 1,
@@ -100,6 +102,7 @@ test_that("check plot stuff", {
       fit.method = "EXP",
       sequence.structure = c("TL", paste0("pseudoIRSL", 1:6)),
       main = "Pseudo pIRIR data set based on quartz OSL",
+      cex = 0.5,
       plot = TRUE,
       verbose = FALSE))
   dev.off()
@@ -145,6 +148,8 @@ test_that("input validation", {
                                      background.integral.min = 900,
                                      background.integral.max = 1000),
                "'object' should be of class 'RLum.Analysis'")
+  expect_error(analyse_pIRIRSequence(object),
+               "'signal.integral.min' should be of class 'integer' or 'numeric'")
   expect_error(analyse_pIRIRSequence(object,
                                      signal.integral.min = 1,
                                      signal.integral.max = 2,
@@ -161,6 +166,9 @@ test_that("input validation", {
                "'error' not allowed in 'sequence.structure'")
 
   SW({
+  expect_warning(expect_error(analyse_pIRIRSequence(list(object)),
+                              "'background.integral.min' should be of class"),
+                 "'signal.integral.min' missing, set to 1")
   expect_warning(analyse_pIRIRSequence(list(object),
                                        signal.integral.max = 2,
                                        background.integral.min = 900,
@@ -227,3 +235,46 @@ test_that("check class and length of output", {
    expect_equal(round(sum(results$data[1:2, 1:4]), 0),7584)
    expect_equal(round(sum(results$rejection.criteria$Value), 2),3338.69)
 })
+
+test_that("regression tests", {
+  testthat::skip_on_cran()
+
+  ## issue 838
+  object.mod <- object
+  object.mod@records <- lapply(object.mod@records, function(x) {
+    x@recordType <- paste(x@recordType, "(UVVIS)")
+    x
+  })
+  expect_s4_class(analyse_pIRIRSequence(object.mod,
+                                        signal.integral.min = 1,
+                                        signal.integral.max = 10,
+                                        background.integral.min = 900,
+                                        background.integral.max = 1000,
+                                        plot = FALSE,
+                                        verbose = FALSE),
+               "RLum.Results")
+})
+
+test_that("graphical snapshot tests", {
+  testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
+  testthat::skip_if_not(getRversion() >= "4.4.0")
+
+  set.seed(1)
+  SW({
+    vdiffr::expect_doppelganger("default",
+                                analyse_pIRIRSequence(
+                                  object,
+                                  signal.integral.min = 1,
+                                  signal.integral.max = 2,
+                                  background.integral.min = 900,
+                                  background.integral.max = 1000,
+                                  fit.method = "EXP",
+                                  sequence.structure = c("TL", "pseudoIRSL1", "pseudoIRSL2"),
+                                  main = "Pseudo pIRIR data set based on quartz OSL",
+                                  plot = TRUE,
+                                  plot_singlePanels = FALSE,
+                                  verbose = FALSE))
+
+  })
+})
