@@ -6,12 +6,19 @@ df <-
 
 temp <- calc_HomogeneityTest(df, verbose = FALSE)
 
-
-test_that("check class and length of output", {
+test_that("input validation", {
   testthat::skip_on_cran()
 
   expect_error(calc_HomogeneityTest(TRUE),
-               "'data' object has to be of type 'data.frame' or 'RLum.Results'")
+               "'data' should be of class 'data.frame' or 'RLum.Results'")
+  expect_error(calc_HomogeneityTest(data.frame()),
+               "'data' cannot be an empty data.frame")
+  expect_error(calc_HomogeneityTest(iris[, 1, drop = FALSE]),
+               "'data' should have 2 columns")
+})
+
+test_that("check values from output example", {
+  testthat::skip_on_cran()
 
   expect_s4_class(temp, "RLum.Results")
   expect_equal(length(temp), 3)
@@ -21,10 +28,6 @@ test_that("check class and length of output", {
   expect_s4_class(calc_HomogeneityTest(temp),
                   "RLum.Results")
   })
-})
-
-test_that("check values from output example", {
-  testthat::skip_on_cran()
 
   results <- get_RLum(temp)
 
@@ -39,4 +42,19 @@ test_that("check values from output example", {
   temp <- calc_HomogeneityTest(df, log = FALSE)$summary
   })
   expect_equal(round(temp$P.value,3),0.001)
+
+  ## negative values in data
+  expect_warning(expect_warning(
+      calc_HomogeneityTest(data.frame(1:5, -1:3), verbose = FALSE),
+      "'data' contains negative values and 'log = TRUE'"),
+      "NaNs produced")
+})
+
+test_that("regression tests", {
+  testthat::skip_on_cran()
+
+  ## issue 924
+  expect_s4_class(
+      calc_HomogeneityTest(data.frame(1:4, NA), verbose = FALSE),
+      "RLum.Results")
 })
