@@ -1,7 +1,23 @@
-test_that("test convert functions", {
+test_that("input validation", {
   testthat::skip_on_cran()
 
-  # Set up test scenario ------------------------------------------------------------------------
+  expect_error(convert_Wavelength2Energy("test"),
+               "'object' should be of class 'RLum.Data.Spectrum', 'data.frame'")
+  expect_error(convert_Wavelength2Energy(data.frame()),
+               "'object' cannot be an empty data.frame")
+  expect_error(convert_Wavelength2Energy(matrix()),
+               "'object' should have at least two columns")
+  expect_error(convert_Wavelength2Energy(list(iris)),
+               "'object' should have only numeric fields")
+  expect_error(convert_Wavelength2Energy(set_RLum("RLum.Data.Spectrum")),
+               "'object' contains no data")
+})
+
+test_that("check functionality", {
+  testthat::skip_on_cran()
+
+  ## Set up test scenario ---------------------------------------------------
+
   #create artifical dataset according to Mooney et al. (2013)
   lambda <- seq(400,800,50)
   data <- matrix(data = rep(1, 2 * length(lambda)), ncol = 2)
@@ -14,19 +30,18 @@ test_that("test convert functions", {
     polygon(x = c(m[, 1], rev(m[, 1])), y = c(m[, 2], rep(0, nrow(m))))
     for (i in 1:nrow(m)) {
       lines(x = rep(m[i, 1], 2), y = c(0, m[i, 2]))
-
     }
   }
 
-  # Test ----------------------------------------------------------------------------------------
-  ##crash function
-  expect_error(convert_Wavelength2Energy("test"), regexp = "Class 'character' not supported as input!")
+  ## Test --------------------------------------------------------------------
 
   ##test all three allowed input objects
   expect_type(convert_Wavelength2Energy(data), "double")
   expect_s3_class(convert_Wavelength2Energy(as.data.frame(data)), class = "data.frame")
   object <- set_RLum(class = "RLum.Data.Spectrum", data = data[,1,drop = FALSE])
   expect_s4_class(convert_Wavelength2Energy(object), class = "RLum.Data.Spectrum")
+  expect_type(convert_Wavelength2Energy(matrix(rnorm(5), 1, 5)),
+              "double")
 
   ##test the list option
   expect_type(convert_Wavelength2Energy(list(data, as.data.frame(data), object)), "list")
@@ -39,7 +54,8 @@ test_that("test convert functions", {
 
   ##test special treatment of RLum.Data.Spectrum objects
   object@info[["curveDescripter"]] <- "energy"
-  expect_message(convert_Wavelength2Energy(object), regexp = "Your object has already an energy scale, nothing done!")
+  expect_message(convert_Wavelength2Energy(object),
+                 "'object' has already an energy scale, nothing done")
   object@info[["curveDescripter"]] <- "wavelength"
   res <- convert_Wavelength2Energy(object)
   expect_equal(res@info[["curveDescripter"]],
@@ -62,6 +78,4 @@ test_that("test convert functions", {
   # par(mfrow = c(1,2))
   # plot_RLum.Data.Spectrum(object, plot.type = "single", par.local = FALSE)
   # plot_RLum.Data.Spectrum(convert_Wavelength2Energy(object), plot.type = "single", par.local = FALSE)
-
-
 })
