@@ -1,6 +1,25 @@
 ## load data
 data(ExampleData.LxTxData, envir = environment())
 
+## odd data set where the calculated De is negative for EXP
+df_odd <- data.frame(
+    dose = c(
+      0, 0, 2.71828182845905, 2.74202785430992,
+      2.76598131771852, 2.79014403079188, 2.814517821467, 2.83910453364916,
+      2.86390602735137, 2.88892417883514, 2.91416088075237, 2.93961804228855,
+      2.96529758930721, 2.99120146449558, 3.01733162751159, 3.04369005513209,
+      3.07027874140241, 3.09709969778723, 3.1241549533227, 3.15144655477),
+    LxTx = c(0.439, 0.851865307456887, 0.881530377359027, 0.881788046363334,
+      0.882047940677405, 0.882310079298982, 0.882574481384203, 0.882841166248859,
+      0.883110153369655, 0.883381462385488, 0.883655113098727, 0.883931125476509,
+      0.884209519652028, 0.88449031592586, 0.884773534767266, 0.885059196815536,
+      0.885347322881313, 0.885637933947948, 0.885931051172847, 0.886226695888845),
+    LxTx.error = c(0.029, 1e-04, 0.0393190034426231, 0.0393304962836274,
+      0.0393420883803856, 0.0393537805802564, 0.0393655737376631, 0.0393774687141504,
+      0.03938946637844, 0.0394015676064878, 0.0394137732815415, 0.0394260842941973,
+      0.0394385015424588, 0.0394510259317946, 0.0394636583751979, 0.0394763997932453,
+      0.0394892511141562, 0.0395022132738537, 0.0395152872160239, 0.0395284738921779))
+
 test_that("input validation", {
   testthat::skip_on_cran()
 
@@ -11,6 +30,8 @@ test_that("input validation", {
       fixed = TRUE)
   expect_error(fit_DoseResponseCurve(data.frame()),
                "'object' cannot be an empty data.frame")
+  expect_error(fit_DoseResponseCurve(iris[, 1, drop = FALSE]),
+               "'object' should have at least 2 columns")
   expect_error(fit_DoseResponseCurve(as.list(LxTxData)),
                "All elements of 'object' should be of class 'data.frame'")
 
@@ -124,32 +145,9 @@ test_that("weird LxTx values", {
       fit.includingRepeatedRegPoints = FALSE),
     class = "RLum.Results")
 
-  ## use odd data set where the calculated De is negative for EXP
-  df_odd <- structure(list(dose = c(0, 0, 2.71828182845905, 2.74202785430992,
-      2.76598131771852, 2.79014403079188, 2.814517821467, 2.83910453364916,
-      2.86390602735137, 2.88892417883514, 2.91416088075237, 2.93961804228855,
-      2.96529758930721, 2.99120146449558, 3.01733162751159, 3.04369005513209,
-      3.07027874140241, 3.09709969778723, 3.1241549533227, 3.15144655477
-      ), LxTx = c(0.439, 0.851865307456887, 0.881530377359027, 0.881788046363334,
-      0.882047940677405, 0.882310079298982, 0.882574481384203, 0.882841166248859,
-      0.883110153369655, 0.883381462385488, 0.883655113098727, 0.883931125476509,
-      0.884209519652028, 0.88449031592586, 0.884773534767266, 0.885059196815536,
-      0.885347322881313, 0.885637933947948, 0.885931051172847, 0.886226695888845
-      ), LxTx.error = c(0.029, 1e-04, 0.0393190034426231, 0.0393304962836274,
-      0.0393420883803856, 0.0393537805802564, 0.0393655737376631, 0.0393774687141504,
-      0.03938946637844, 0.0394015676064878, 0.0394137732815415, 0.0394260842941973,
-      0.0394385015424588, 0.0394510259317946, 0.0394636583751979, 0.0394763997932453,
-      0.0394892511141562, 0.0395022132738537, 0.0395152872160239, 0.0395284738921779
-      )), row.names = c(NA, 20L), class = "data.frame")
-
-  ## do not include reg point
-  t <- expect_s4_class(
-    fit_DoseResponseCurve(
-      df_odd,
-      verbose = FALSE),
-    class = "RLum.Results")
-
-  expect_true(is.na(t$De[[1]]))
+  ## issue 961
+  expect_output(fit_DoseResponseCurve(df_odd, fit.method = "QDR"),
+                "Fit failed for QDR (interpolation)", fixed = TRUE)
 })
 
 test_that("snapshot tests", {
@@ -264,6 +262,21 @@ test_that("snapshot tests", {
       verbose = TRUE,
       n.MC = 10
   ), tolerance = 5.0e-5)
+
+  ## negative De
+  expect_snapshot_RLum(fit_DoseResponseCurve(
+      df_odd,
+      mode = "interpolation",
+      verbose = FALSE,
+      n.MC = 10
+  ), tolerance = 5.0e-3)
+
+  expect_snapshot_RLum(fit_DoseResponseCurve(
+      df_odd,
+      mode = "extrapolation",
+      verbose = FALSE,
+      n.MC = 10
+  ), tolerance = 4.0e-2)
   })
 })
 
